# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from . import (
        auth,
        billing_notes,
        charge_capture,
        charge_capture_bundles,
        claim_submission,
        claims,
        clinical_trials,
        commons,
        contracts,
        credentialing,
        custom_schemas,
        diagnoses,
        eligibility,
        encounter_attachments,
        encounter_providers,
        encounter_supplemental_information,
        encounters,
        encounters_universal,
        eras,
        events,
        exports,
        external_payment_account_config,
        fee_schedules,
        financials,
        guarantor,
        health_care_code_information,
        identifiers,
        import_invoice,
        individual,
        insurance_adjudications,
        insurance_cards,
        insurance_refunds,
        invoices,
        medication_dispense,
        non_insurance_payer_payments,
        non_insurance_payer_refunds,
        non_insurance_payers,
        organization_providers,
        organization_service_facilities,
        patient_ar,
        patient_payments,
        patient_refunds,
        payer_plan_groups,
        payers,
        payment_account_configs,
        pipeline_commons,
        pre_encounter,
        property_and_casualty,
        related_causes,
        service_facility,
        service_lines,
        superbills,
        tags,
        tasks,
        users,
        write_offs,
        x_12,
        yes_no_indicator,
    )
    from .claims import Claim, ClaimStatus
    from .commons import (
        AdjustmentId,
        AppointmentId,
        BadRequestError,
        BadRequestErrorMessage,
        BillingProviderCommercialLicenseType,
        ChargeCaptureClaimCreationId,
        ChargeCaptureId,
        ChargeCapturePostBilledChangeId,
        ClaimAdjustmentGroupCodes,
        ClaimId,
        ClaimSubmissionPayerResponsibilityType,
        Clearinghouse,
        ClinicalTrialId,
        Date,
        DateRangeOptionalEnd,
        Decimal,
        DelayReasonCode,
        Email,
        EmrPayerCrosswalk,
        EncounterExternalId,
        EncounterId,
        EntityConflictError,
        EntityConflictErrorMessage,
        EntityNotFoundError,
        EntityNotFoundErrorMessage,
        EpsdtReferralConditionIndicatorCode,
        ErrorMessage,
        FacilityTypeCode,
        HttpRequestValidationError,
        HttpRequestValidationsError,
        InsuranceTypeCode,
        IntendedSubmissionMedium,
        InternalError,
        InternalErrorMessage,
        InvoiceId,
        LinkUrl,
        NetworkType,
        NextResponsibleParty,
        Npi,
        OrganizationId,
        OrganizationNotAuthorizedError,
        OrganizationNotAuthorizedErrorMessage,
        PageToken,
        PatientExternalId,
        PatientRelationshipToInsuredCodeAll,
        PayerPlanGroupId,
        PhoneNumber,
        PhoneNumberOptional,
        PhoneNumberType,
        PreEncounterAppointmentId,
        PreEncounterPatientId,
        Primitive,
        ProcedureModifier,
        ProviderCredentialingSpanId,
        ProviderId,
        QualifierCode,
        RateId,
        RegionNational,
        RegionStates,
        Regions,
        Regions_National,
        Regions_States,
        RemovableDateRangeOptionalEnd,
        RemovableDateRangeOptionalEnd_DateRange,
        RemovableDateRangeOptionalEnd_Remove,
        ReportTransmissionCode,
        ReportTypeCode,
        RequestValidationError,
        ResourcePage,
        SchemaId,
        ServiceLineId,
        ServiceLineUnits,
        SortDirection,
        SourceOfPaymentCode,
        State,
        StreetAddressBase,
        StreetAddressLongZip,
        StreetAddressLongZipOptional,
        StreetAddressOptionalBase,
        StreetAddressShortZip,
        StreetAddressShortZipOptional,
        TaskAssignmentId,
        TaskId,
        TaskNoteId,
        UnauthorizedError,
        UnauthorizedErrorMessage,
        UnprocessableEntityError,
        UnprocessableEntityErrorMessage,
        UpdatesDisabledDueToExternalSystemIntegrationError,
        UpdatesDisabledDueToExternalSystemIntegrationErrorMessage,
        UserId,
        WorkQueueId,
    )
    from .diagnoses import (
        Diagnosis,
        DiagnosisCreate,
        DiagnosisCreateOptional,
        DiagnosisId,
        DiagnosisNotFoundError,
        DiagnosisNotFoundHttpError,
        DiagnosisTypeCode,
        DisallowMultiplePrimaryDiagnosisError,
        DisallowMultiplePrimaryDiagnosisHttpError,
        ServiceLinesMustHaveAtLeastOneDiagnosisError,
        ServiceLinesMustHaveAtLeastOneDiagnosisHttpError,
        StandaloneDiagnosisCreate,
    )
    from .eras import Era, EraBase, EraId
    from .financials import (
        AccountType,
        Allocation,
        AllocationCreate,
        AllocationEarmarkType,
        AllocationEarmarkType_DateOfService,
        AllocationEarmarkType_ExternalEncounterId,
        AllocationTarget,
        AllocationTargetCreate,
        AllocationTargetCreate_AppointmentByIdAndPatientExternalId,
        AllocationTargetCreate_BillingProviderById,
        AllocationTargetCreate_ClaimByEncounterExternalId,
        AllocationTargetCreate_ClaimById,
        AllocationTargetCreate_ServiceLineById,
        AllocationTargetCreate_Unattributed,
        AllocationTarget_Appointment,
        AllocationTarget_BillingProviderId,
        AllocationTarget_Claim,
        AllocationTarget_ServiceLine,
        AllocationTarget_Unattributed,
        AppointmentAllocationTarget,
        AppointmentByIdAndPatientExternalId,
        BalanceEarmark,
        BillingProviderAllocationTarget,
        ClaimAllocationTarget,
        InvoiceUpdate,
        InvoiceUpdate_Remove,
        InvoiceUpdate_Set,
        NoteUpdate,
        NoteUpdate_Remove,
        NoteUpdate_Set,
        PatientTransactionSource,
        RefundReason,
        RefundReasonUpdate,
        RefundReasonUpdate_Remove,
        RefundReasonUpdate_Set,
        ServiceLineAllocationTarget,
    )
    from .identifiers import (
        Identifier,
        IdentifierBase,
        IdentifierCode,
        IdentifierCreate,
        IdentifierId,
        IdentifierUpdate,
        IdentifierValue,
        IdentifierValue_MedicaidProviderIdentifier,
        IdentifierValue_MedicareProviderIdentifier,
        MedicaidProviderIdentifier,
        MedicareProviderIdentifier,
        UpdatableIdentifier,
        UpdatableIdentifier_Add,
        UpdatableIdentifier_Remove,
        UpdatableIdentifier_Update,
    )
    from .individual import (
        Gender,
        IndividualBase,
        IndividualBaseOptional,
        IndividualId,
        Patient,
        PatientBase,
        PatientClinicalTrialInfo,
        PatientClinicalTrialInfoCreate,
        PatientCreate,
        PatientNonInsurancePayerInfo,
        PatientNonInsurancePayerInfoCreate,
        PatientNonInsurancePayerInfoCreateOptional,
        PatientUpdate,
        PatientUpdateWithOptionalAddress,
        Subscriber,
        SubscriberBase,
        SubscriberBaseOptional,
        SubscriberCreate,
        SubscriberCreateOptional,
    )
    from .invoices import Invoice, InvoiceItem, InvoiceStatus
    from .payment_account_configs import PaymentAccountConfigId
    from .pipeline_commons import ConfigurableRuleId
    from .service_facility import (
        EncounterServiceFacility,
        EncounterServiceFacilityBase,
        EncounterServiceFacilityUpdate,
        EncounterServiceFacilityUpdateWithOptionalAddress,
        ServiceFacilityId,
    )
    from .tags import Tag, TagColorEnum, TagCreate, TagId
    from .yes_no_indicator import YesNoIndicator
_dynamic_imports: typing.Dict[str, str] = {
    "AccountType": ".financials",
    "AdjustmentId": ".commons",
    "Allocation": ".financials",
    "AllocationCreate": ".financials",
    "AllocationEarmarkType": ".financials",
    "AllocationEarmarkType_DateOfService": ".financials",
    "AllocationEarmarkType_ExternalEncounterId": ".financials",
    "AllocationTarget": ".financials",
    "AllocationTargetCreate": ".financials",
    "AllocationTargetCreate_AppointmentByIdAndPatientExternalId": ".financials",
    "AllocationTargetCreate_BillingProviderById": ".financials",
    "AllocationTargetCreate_ClaimByEncounterExternalId": ".financials",
    "AllocationTargetCreate_ClaimById": ".financials",
    "AllocationTargetCreate_ServiceLineById": ".financials",
    "AllocationTargetCreate_Unattributed": ".financials",
    "AllocationTarget_Appointment": ".financials",
    "AllocationTarget_BillingProviderId": ".financials",
    "AllocationTarget_Claim": ".financials",
    "AllocationTarget_ServiceLine": ".financials",
    "AllocationTarget_Unattributed": ".financials",
    "AppointmentAllocationTarget": ".financials",
    "AppointmentByIdAndPatientExternalId": ".financials",
    "AppointmentId": ".commons",
    "BadRequestError": ".commons",
    "BadRequestErrorMessage": ".commons",
    "BalanceEarmark": ".financials",
    "BillingProviderAllocationTarget": ".financials",
    "BillingProviderCommercialLicenseType": ".commons",
    "ChargeCaptureClaimCreationId": ".commons",
    "ChargeCaptureId": ".commons",
    "ChargeCapturePostBilledChangeId": ".commons",
    "Claim": ".claims",
    "ClaimAdjustmentGroupCodes": ".commons",
    "ClaimAllocationTarget": ".financials",
    "ClaimId": ".commons",
    "ClaimStatus": ".claims",
    "ClaimSubmissionPayerResponsibilityType": ".commons",
    "Clearinghouse": ".commons",
    "ClinicalTrialId": ".commons",
    "ConfigurableRuleId": ".pipeline_commons",
    "Date": ".commons",
    "DateRangeOptionalEnd": ".commons",
    "Decimal": ".commons",
    "DelayReasonCode": ".commons",
    "Diagnosis": ".diagnoses",
    "DiagnosisCreate": ".diagnoses",
    "DiagnosisCreateOptional": ".diagnoses",
    "DiagnosisId": ".diagnoses",
    "DiagnosisNotFoundError": ".diagnoses",
    "DiagnosisNotFoundHttpError": ".diagnoses",
    "DiagnosisTypeCode": ".diagnoses",
    "DisallowMultiplePrimaryDiagnosisError": ".diagnoses",
    "DisallowMultiplePrimaryDiagnosisHttpError": ".diagnoses",
    "Email": ".commons",
    "EmrPayerCrosswalk": ".commons",
    "EncounterExternalId": ".commons",
    "EncounterId": ".commons",
    "EncounterServiceFacility": ".service_facility",
    "EncounterServiceFacilityBase": ".service_facility",
    "EncounterServiceFacilityUpdate": ".service_facility",
    "EncounterServiceFacilityUpdateWithOptionalAddress": ".service_facility",
    "EntityConflictError": ".commons",
    "EntityConflictErrorMessage": ".commons",
    "EntityNotFoundError": ".commons",
    "EntityNotFoundErrorMessage": ".commons",
    "EpsdtReferralConditionIndicatorCode": ".commons",
    "Era": ".eras",
    "EraBase": ".eras",
    "EraId": ".eras",
    "ErrorMessage": ".commons",
    "FacilityTypeCode": ".commons",
    "Gender": ".individual",
    "HttpRequestValidationError": ".commons",
    "HttpRequestValidationsError": ".commons",
    "Identifier": ".identifiers",
    "IdentifierBase": ".identifiers",
    "IdentifierCode": ".identifiers",
    "IdentifierCreate": ".identifiers",
    "IdentifierId": ".identifiers",
    "IdentifierUpdate": ".identifiers",
    "IdentifierValue": ".identifiers",
    "IdentifierValue_MedicaidProviderIdentifier": ".identifiers",
    "IdentifierValue_MedicareProviderIdentifier": ".identifiers",
    "IndividualBase": ".individual",
    "IndividualBaseOptional": ".individual",
    "IndividualId": ".individual",
    "InsuranceTypeCode": ".commons",
    "IntendedSubmissionMedium": ".commons",
    "InternalError": ".commons",
    "InternalErrorMessage": ".commons",
    "Invoice": ".invoices",
    "InvoiceId": ".commons",
    "InvoiceItem": ".invoices",
    "InvoiceStatus": ".invoices",
    "InvoiceUpdate": ".financials",
    "InvoiceUpdate_Remove": ".financials",
    "InvoiceUpdate_Set": ".financials",
    "LinkUrl": ".commons",
    "MedicaidProviderIdentifier": ".identifiers",
    "MedicareProviderIdentifier": ".identifiers",
    "NetworkType": ".commons",
    "NextResponsibleParty": ".commons",
    "NoteUpdate": ".financials",
    "NoteUpdate_Remove": ".financials",
    "NoteUpdate_Set": ".financials",
    "Npi": ".commons",
    "OrganizationId": ".commons",
    "OrganizationNotAuthorizedError": ".commons",
    "OrganizationNotAuthorizedErrorMessage": ".commons",
    "PageToken": ".commons",
    "Patient": ".individual",
    "PatientBase": ".individual",
    "PatientClinicalTrialInfo": ".individual",
    "PatientClinicalTrialInfoCreate": ".individual",
    "PatientCreate": ".individual",
    "PatientExternalId": ".commons",
    "PatientNonInsurancePayerInfo": ".individual",
    "PatientNonInsurancePayerInfoCreate": ".individual",
    "PatientNonInsurancePayerInfoCreateOptional": ".individual",
    "PatientRelationshipToInsuredCodeAll": ".commons",
    "PatientTransactionSource": ".financials",
    "PatientUpdate": ".individual",
    "PatientUpdateWithOptionalAddress": ".individual",
    "PayerPlanGroupId": ".commons",
    "PaymentAccountConfigId": ".payment_account_configs",
    "PhoneNumber": ".commons",
    "PhoneNumberOptional": ".commons",
    "PhoneNumberType": ".commons",
    "PreEncounterAppointmentId": ".commons",
    "PreEncounterPatientId": ".commons",
    "Primitive": ".commons",
    "ProcedureModifier": ".commons",
    "ProviderCredentialingSpanId": ".commons",
    "ProviderId": ".commons",
    "QualifierCode": ".commons",
    "RateId": ".commons",
    "RefundReason": ".financials",
    "RefundReasonUpdate": ".financials",
    "RefundReasonUpdate_Remove": ".financials",
    "RefundReasonUpdate_Set": ".financials",
    "RegionNational": ".commons",
    "RegionStates": ".commons",
    "Regions": ".commons",
    "Regions_National": ".commons",
    "Regions_States": ".commons",
    "RemovableDateRangeOptionalEnd": ".commons",
    "RemovableDateRangeOptionalEnd_DateRange": ".commons",
    "RemovableDateRangeOptionalEnd_Remove": ".commons",
    "ReportTransmissionCode": ".commons",
    "ReportTypeCode": ".commons",
    "RequestValidationError": ".commons",
    "ResourcePage": ".commons",
    "SchemaId": ".commons",
    "ServiceFacilityId": ".service_facility",
    "ServiceLineAllocationTarget": ".financials",
    "ServiceLineId": ".commons",
    "ServiceLineUnits": ".commons",
    "ServiceLinesMustHaveAtLeastOneDiagnosisError": ".diagnoses",
    "ServiceLinesMustHaveAtLeastOneDiagnosisHttpError": ".diagnoses",
    "SortDirection": ".commons",
    "SourceOfPaymentCode": ".commons",
    "StandaloneDiagnosisCreate": ".diagnoses",
    "State": ".commons",
    "StreetAddressBase": ".commons",
    "StreetAddressLongZip": ".commons",
    "StreetAddressLongZipOptional": ".commons",
    "StreetAddressOptionalBase": ".commons",
    "StreetAddressShortZip": ".commons",
    "StreetAddressShortZipOptional": ".commons",
    "Subscriber": ".individual",
    "SubscriberBase": ".individual",
    "SubscriberBaseOptional": ".individual",
    "SubscriberCreate": ".individual",
    "SubscriberCreateOptional": ".individual",
    "Tag": ".tags",
    "TagColorEnum": ".tags",
    "TagCreate": ".tags",
    "TagId": ".tags",
    "TaskAssignmentId": ".commons",
    "TaskId": ".commons",
    "TaskNoteId": ".commons",
    "UnauthorizedError": ".commons",
    "UnauthorizedErrorMessage": ".commons",
    "UnprocessableEntityError": ".commons",
    "UnprocessableEntityErrorMessage": ".commons",
    "UpdatableIdentifier": ".identifiers",
    "UpdatableIdentifier_Add": ".identifiers",
    "UpdatableIdentifier_Remove": ".identifiers",
    "UpdatableIdentifier_Update": ".identifiers",
    "UpdatesDisabledDueToExternalSystemIntegrationError": ".commons",
    "UpdatesDisabledDueToExternalSystemIntegrationErrorMessage": ".commons",
    "UserId": ".commons",
    "WorkQueueId": ".commons",
    "YesNoIndicator": ".yes_no_indicator",
    "auth": ".auth",
    "billing_notes": ".billing_notes",
    "charge_capture": ".charge_capture",
    "charge_capture_bundles": ".charge_capture_bundles",
    "claim_submission": ".claim_submission",
    "claims": ".claims",
    "clinical_trials": ".clinical_trials",
    "commons": ".commons",
    "contracts": ".contracts",
    "credentialing": ".credentialing",
    "custom_schemas": ".custom_schemas",
    "diagnoses": ".diagnoses",
    "eligibility": ".eligibility",
    "encounter_attachments": ".encounter_attachments",
    "encounter_providers": ".encounter_providers",
    "encounter_supplemental_information": ".encounter_supplemental_information",
    "encounters": ".encounters",
    "encounters_universal": ".encounters_universal",
    "eras": ".eras",
    "events": ".events",
    "exports": ".exports",
    "external_payment_account_config": ".external_payment_account_config",
    "fee_schedules": ".fee_schedules",
    "financials": ".financials",
    "guarantor": ".guarantor",
    "health_care_code_information": ".health_care_code_information",
    "identifiers": ".identifiers",
    "import_invoice": ".import_invoice",
    "individual": ".individual",
    "insurance_adjudications": ".insurance_adjudications",
    "insurance_cards": ".insurance_cards",
    "insurance_refunds": ".insurance_refunds",
    "invoices": ".invoices",
    "medication_dispense": ".medication_dispense",
    "non_insurance_payer_payments": ".non_insurance_payer_payments",
    "non_insurance_payer_refunds": ".non_insurance_payer_refunds",
    "non_insurance_payers": ".non_insurance_payers",
    "organization_providers": ".organization_providers",
    "organization_service_facilities": ".organization_service_facilities",
    "patient_ar": ".patient_ar",
    "patient_payments": ".patient_payments",
    "patient_refunds": ".patient_refunds",
    "payer_plan_groups": ".payer_plan_groups",
    "payers": ".payers",
    "payment_account_configs": ".payment_account_configs",
    "pipeline_commons": ".pipeline_commons",
    "pre_encounter": ".pre_encounter",
    "property_and_casualty": ".property_and_casualty",
    "related_causes": ".related_causes",
    "service_facility": ".service_facility",
    "service_lines": ".service_lines",
    "superbills": ".superbills",
    "tags": ".tags",
    "tasks": ".tasks",
    "users": ".users",
    "write_offs": ".write_offs",
    "x_12": ".x_12",
    "yes_no_indicator": ".yes_no_indicator",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "AccountType",
    "AdjustmentId",
    "Allocation",
    "AllocationCreate",
    "AllocationEarmarkType",
    "AllocationEarmarkType_DateOfService",
    "AllocationEarmarkType_ExternalEncounterId",
    "AllocationTarget",
    "AllocationTargetCreate",
    "AllocationTargetCreate_AppointmentByIdAndPatientExternalId",
    "AllocationTargetCreate_BillingProviderById",
    "AllocationTargetCreate_ClaimByEncounterExternalId",
    "AllocationTargetCreate_ClaimById",
    "AllocationTargetCreate_ServiceLineById",
    "AllocationTargetCreate_Unattributed",
    "AllocationTarget_Appointment",
    "AllocationTarget_BillingProviderId",
    "AllocationTarget_Claim",
    "AllocationTarget_ServiceLine",
    "AllocationTarget_Unattributed",
    "AppointmentAllocationTarget",
    "AppointmentByIdAndPatientExternalId",
    "AppointmentId",
    "BadRequestError",
    "BadRequestErrorMessage",
    "BalanceEarmark",
    "BillingProviderAllocationTarget",
    "BillingProviderCommercialLicenseType",
    "ChargeCaptureClaimCreationId",
    "ChargeCaptureId",
    "ChargeCapturePostBilledChangeId",
    "Claim",
    "ClaimAdjustmentGroupCodes",
    "ClaimAllocationTarget",
    "ClaimId",
    "ClaimStatus",
    "ClaimSubmissionPayerResponsibilityType",
    "Clearinghouse",
    "ClinicalTrialId",
    "ConfigurableRuleId",
    "Date",
    "DateRangeOptionalEnd",
    "Decimal",
    "DelayReasonCode",
    "Diagnosis",
    "DiagnosisCreate",
    "DiagnosisCreateOptional",
    "DiagnosisId",
    "DiagnosisNotFoundError",
    "DiagnosisNotFoundHttpError",
    "DiagnosisTypeCode",
    "DisallowMultiplePrimaryDiagnosisError",
    "DisallowMultiplePrimaryDiagnosisHttpError",
    "Email",
    "EmrPayerCrosswalk",
    "EncounterExternalId",
    "EncounterId",
    "EncounterServiceFacility",
    "EncounterServiceFacilityBase",
    "EncounterServiceFacilityUpdate",
    "EncounterServiceFacilityUpdateWithOptionalAddress",
    "EntityConflictError",
    "EntityConflictErrorMessage",
    "EntityNotFoundError",
    "EntityNotFoundErrorMessage",
    "EpsdtReferralConditionIndicatorCode",
    "Era",
    "EraBase",
    "EraId",
    "ErrorMessage",
    "FacilityTypeCode",
    "Gender",
    "HttpRequestValidationError",
    "HttpRequestValidationsError",
    "Identifier",
    "IdentifierBase",
    "IdentifierCode",
    "IdentifierCreate",
    "IdentifierId",
    "IdentifierUpdate",
    "IdentifierValue",
    "IdentifierValue_MedicaidProviderIdentifier",
    "IdentifierValue_MedicareProviderIdentifier",
    "IndividualBase",
    "IndividualBaseOptional",
    "IndividualId",
    "InsuranceTypeCode",
    "IntendedSubmissionMedium",
    "InternalError",
    "InternalErrorMessage",
    "Invoice",
    "InvoiceId",
    "InvoiceItem",
    "InvoiceStatus",
    "InvoiceUpdate",
    "InvoiceUpdate_Remove",
    "InvoiceUpdate_Set",
    "LinkUrl",
    "MedicaidProviderIdentifier",
    "MedicareProviderIdentifier",
    "NetworkType",
    "NextResponsibleParty",
    "NoteUpdate",
    "NoteUpdate_Remove",
    "NoteUpdate_Set",
    "Npi",
    "OrganizationId",
    "OrganizationNotAuthorizedError",
    "OrganizationNotAuthorizedErrorMessage",
    "PageToken",
    "Patient",
    "PatientBase",
    "PatientClinicalTrialInfo",
    "PatientClinicalTrialInfoCreate",
    "PatientCreate",
    "PatientExternalId",
    "PatientNonInsurancePayerInfo",
    "PatientNonInsurancePayerInfoCreate",
    "PatientNonInsurancePayerInfoCreateOptional",
    "PatientRelationshipToInsuredCodeAll",
    "PatientTransactionSource",
    "PatientUpdate",
    "PatientUpdateWithOptionalAddress",
    "PayerPlanGroupId",
    "PaymentAccountConfigId",
    "PhoneNumber",
    "PhoneNumberOptional",
    "PhoneNumberType",
    "PreEncounterAppointmentId",
    "PreEncounterPatientId",
    "Primitive",
    "ProcedureModifier",
    "ProviderCredentialingSpanId",
    "ProviderId",
    "QualifierCode",
    "RateId",
    "RefundReason",
    "RefundReasonUpdate",
    "RefundReasonUpdate_Remove",
    "RefundReasonUpdate_Set",
    "RegionNational",
    "RegionStates",
    "Regions",
    "Regions_National",
    "Regions_States",
    "RemovableDateRangeOptionalEnd",
    "RemovableDateRangeOptionalEnd_DateRange",
    "RemovableDateRangeOptionalEnd_Remove",
    "ReportTransmissionCode",
    "ReportTypeCode",
    "RequestValidationError",
    "ResourcePage",
    "SchemaId",
    "ServiceFacilityId",
    "ServiceLineAllocationTarget",
    "ServiceLineId",
    "ServiceLineUnits",
    "ServiceLinesMustHaveAtLeastOneDiagnosisError",
    "ServiceLinesMustHaveAtLeastOneDiagnosisHttpError",
    "SortDirection",
    "SourceOfPaymentCode",
    "StandaloneDiagnosisCreate",
    "State",
    "StreetAddressBase",
    "StreetAddressLongZip",
    "StreetAddressLongZipOptional",
    "StreetAddressOptionalBase",
    "StreetAddressShortZip",
    "StreetAddressShortZipOptional",
    "Subscriber",
    "SubscriberBase",
    "SubscriberBaseOptional",
    "SubscriberCreate",
    "SubscriberCreateOptional",
    "Tag",
    "TagColorEnum",
    "TagCreate",
    "TagId",
    "TaskAssignmentId",
    "TaskId",
    "TaskNoteId",
    "UnauthorizedError",
    "UnauthorizedErrorMessage",
    "UnprocessableEntityError",
    "UnprocessableEntityErrorMessage",
    "UpdatableIdentifier",
    "UpdatableIdentifier_Add",
    "UpdatableIdentifier_Remove",
    "UpdatableIdentifier_Update",
    "UpdatesDisabledDueToExternalSystemIntegrationError",
    "UpdatesDisabledDueToExternalSystemIntegrationErrorMessage",
    "UserId",
    "WorkQueueId",
    "YesNoIndicator",
    "auth",
    "billing_notes",
    "charge_capture",
    "charge_capture_bundles",
    "claim_submission",
    "claims",
    "clinical_trials",
    "commons",
    "contracts",
    "credentialing",
    "custom_schemas",
    "diagnoses",
    "eligibility",
    "encounter_attachments",
    "encounter_providers",
    "encounter_supplemental_information",
    "encounters",
    "encounters_universal",
    "eras",
    "events",
    "exports",
    "external_payment_account_config",
    "fee_schedules",
    "financials",
    "guarantor",
    "health_care_code_information",
    "identifiers",
    "import_invoice",
    "individual",
    "insurance_adjudications",
    "insurance_cards",
    "insurance_refunds",
    "invoices",
    "medication_dispense",
    "non_insurance_payer_payments",
    "non_insurance_payer_refunds",
    "non_insurance_payers",
    "organization_providers",
    "organization_service_facilities",
    "patient_ar",
    "patient_payments",
    "patient_refunds",
    "payer_plan_groups",
    "payers",
    "payment_account_configs",
    "pipeline_commons",
    "pre_encounter",
    "property_and_casualty",
    "related_causes",
    "service_facility",
    "service_lines",
    "superbills",
    "tags",
    "tasks",
    "users",
    "write_offs",
    "x_12",
    "yes_no_indicator",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....commons.types.primitive import Primitive


class SchemaField(UniversalBaseModel):
    """
    Examples
    --------
    from candid.resources.commons import Primitive
    from candid.resources.custom_schemas.resources.v_1 import SchemaField

    SchemaField(
        key="provider_category",
        type=Primitive.STRING,
    )
    """

    key: str
    type: Primitive

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ......core import enum

T_Result = typing.TypeVar("T_Result")


class TypeOfFacilityCode(enum.StrEnum):
    C_1 = "1"
    """
    Hospital
    """

    C_2 = "2"
    """
    Skilled Nursing Facility
    """

    C_3 = "3"
    """
    Home Health
    """

    C_4 = "4"
    """
    Religious Nonmedical (Hospital)
    """

    C_6 = "6"
    """
    Intermediate Care
    """

    C_7 = "7"
    """
    Clinic or Hospital based End Stage Renal Disease (ESRD) facility (requires Special second digit)
    """

    C_8 = "8"
    """
    Special facility or hospital (Critical Access Hospital (CAH)) (Ambulatory Surgical Center (ASC)) surgery (requires special second digit)
    """

    _UNKNOWN = "__TYPEOFFACILITYCODE_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "TypeOfFacilityCode":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        c_1: typing.Callable[[], T_Result],
        c_2: typing.Callable[[], T_Result],
        c_3: typing.Callable[[], T_Result],
        c_4: typing.Callable[[], T_Result],
        c_6: typing.Callable[[], T_Result],
        c_7: typing.Callable[[], T_Result],
        c_8: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is TypeOfFacilityCode.C_1:
            return c_1()
        if self is TypeOfFacilityCode.C_2:
            return c_2()
        if self is TypeOfFacilityCode.C_3:
            return c_3()
        if self is TypeOfFacilityCode.C_4:
            return c_4()
        if self is TypeOfFacilityCode.C_6:
            return c_6()
        if self is TypeOfFacilityCode.C_7:
            return c_7()
        if self is TypeOfFacilityCode.C_8:
            return c_8()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....commons.types.organization_id import OrganizationId
from .....commons.types.user_id import UserId
from .idp_user_metadata import IdpUserMetadata
from .user_metadata import UserMetadata


class UserV2(UniversalBaseModel):
    """
    Examples
    --------
    import uuid

    from candid.resources.users.resources.v_2 import (
        IdpUserMetadata_AuthZeroMetadata,
        UserMetadata_HumanUserMetadata,
        UserV2,
    )

    UserV2(
        user_id=uuid.UUID(
            "1503a782-35f6-45a7-b5c3-53ca2ebe8887",
        ),
        idp_metadata=[
            IdpUserMetadata_AuthZeroMetadata(
                auth_0_id="auth0|5f9b3b5a7b0b0d006a2b0b0b",
            )
        ],
        primary_organization_id=uuid.UUID(
            "83a2a782-35f6-45a7-b5c3-53ca2ebe8887",
        ),
        user_metadata=UserMetadata_HumanUserMetadata(
            first_name="John",
            last_name="Doe",
            email="john.doe@example.com",
        ),
    )
    """

    user_id: UserId
    idp_metadata: typing.List[IdpUserMetadata]
    primary_organization_id: typing.Optional[OrganizationId] = None
    user_metadata: UserMetadata

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....commons.types.claim_id import ClaimId
from .....commons.types.encounter_id import EncounterId
from .....commons.types.patient_external_id import PatientExternalId
from .patient_ar_status import PatientArStatus


class InventoryRecord(UniversalBaseModel):
    claim_id: ClaimId
    encounter_id: EncounterId
    timestamp: dt.datetime
    patient_external_id: PatientExternalId
    patient_ar_status: PatientArStatus

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...commons.types.service_line_id import ServiceLineId
from .diagnosis_id import DiagnosisId


class ServiceLinesMustHaveAtLeastOneDiagnosisError(UniversalBaseModel):
    diagnosis_id: DiagnosisId
    service_line_id: ServiceLineId
    message: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class VitalsUpdate(UniversalBaseModel):
    """
    Examples
    --------
    from candid.resources.encounters.resources.v_4 import VitalsUpdate

    VitalsUpdate(
        height_in=70,
        weight_lbs=165,
        blood_pressure_systolic_mmhg=115,
        blood_pressure_diastolic_mmhg=85,
        body_temperature_f=98.0,
        hemoglobin_gdl=15.1,
        hematocrit_pct=51.2,
    )
    """

    height_in: typing.Optional[int] = None
    weight_lbs: typing.Optional[int] = None
    blood_pressure_systolic_mmhg: typing.Optional[int] = None
    blood_pressure_diastolic_mmhg: typing.Optional[int] = None
    body_temperature_f: typing.Optional[float] = None
    hemoglobin_gdl: typing.Optional[float] = None
    hematocrit_pct: typing.Optional[float] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing
from json.decoder import JSONDecodeError

from .....core.api_error import ApiError
from .....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .....core.http_response import AsyncHttpResponse, HttpResponse
from .....core.jsonable_encoder import jsonable_encoder
from .....core.pydantic_utilities import parse_obj_as
from .....core.request_options import RequestOptions
from ....claims.types.claim_status import ClaimStatus
from ....commons.errors.entity_not_found_error import EntityNotFoundError
from ....commons.errors.http_request_validations_error import HttpRequestValidationsError
from ....commons.errors.unauthorized_error import UnauthorizedError
from ....commons.errors.unprocessable_entity_error import UnprocessableEntityError
from ....commons.types.charge_capture_claim_creation_id import ChargeCaptureClaimCreationId
from ....commons.types.charge_capture_id import ChargeCaptureId
from ....commons.types.charge_capture_post_billed_change_id import ChargeCapturePostBilledChangeId
from ....commons.types.encounter_id import EncounterId
from ....commons.types.entity_not_found_error_message import EntityNotFoundErrorMessage
from ....commons.types.page_token import PageToken
from ....commons.types.pre_encounter_appointment_id import PreEncounterAppointmentId
from ....commons.types.pre_encounter_patient_id import PreEncounterPatientId
from ....commons.types.request_validation_error import RequestValidationError
from ....commons.types.sort_direction import SortDirection
from ....commons.types.unauthorized_error_message import UnauthorizedErrorMessage
from ....commons.types.unprocessable_entity_error_message import UnprocessableEntityErrorMessage
from ....encounters.resources.v_4.errors.schema_instance_validation_http_failure import (
    SchemaInstanceValidationHttpFailure,
)
from ....encounters.resources.v_4.types.billable_status_type import BillableStatusType
from ....encounters.resources.v_4.types.responsible_party_type import ResponsiblePartyType
from ....encounters.resources.v_4.types.schema_instance_validation_failure import SchemaInstanceValidationFailure
from .errors.charge_external_id_conflict_error import ChargeExternalIdConflictError
from .types.charge_capture import ChargeCapture
from .types.charge_capture_data import ChargeCaptureData
from .types.charge_capture_page import ChargeCapturePage
from .types.charge_capture_post_billed_change import ChargeCapturePostBilledChange
from .types.charge_capture_sort_field import ChargeCaptureSortField
from .types.charge_capture_status import ChargeCaptureStatus
from .types.charge_external_id_conflict_error_message import ChargeExternalIdConflictErrorMessage

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawV1Client:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def create(
        self,
        *,
        data: ChargeCaptureData,
        charge_external_id: str,
        patient_external_id: str,
        status: ChargeCaptureStatus,
        originating_system: typing.Optional[str] = OMIT,
        claim_creation_category: typing.Optional[str] = OMIT,
        ehr_source_url: typing.Optional[str] = OMIT,
        attachment_external_document_ids: typing.Optional[typing.Sequence[str]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[ChargeCapture]:
        """
        Parameters
        ----------
        data : ChargeCaptureData
            Charge Capture data contains all the fields needed to create an encounter, but listed as optional. Candid will use this data when attempting to bundle multiple Charge Captures into a single encounter.

        charge_external_id : str
            A client-specified unique ID to associate with this encounter; for example, your internal encounter ID or a Dr. Chrono encounter ID. This field should not contain PHI.

        patient_external_id : str
            The patient ID from the external EMR platform for the patient

        status : ChargeCaptureStatus
            the status of the charge capture

        originating_system : typing.Optional[str]
            An optional string field denoting the originating system of the charge.

        claim_creation_category : typing.Optional[str]
            An optional string field denoting the user defined category of the claim creation.

        ehr_source_url : typing.Optional[str]
            External URL reference that links to Charge Capture details within the external system (e.g. the EHR visit page). Send full URL format for the external link (e.g. https://emr_charge_capture_url.com/123).

        attachment_external_document_ids : typing.Optional[typing.Sequence[str]]
            Provide external attachment IDs which have been uploaded to Candid. They will be associated with the Encounter at Encounter creation time.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ChargeCapture]
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/charge_captures/v1",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="POST",
            json={
                "data": data,
                "charge_external_id": charge_external_id,
                "originating_system": originating_system,
                "claim_creation_category": claim_creation_category,
                "ehr_source_url": ehr_source_url,
                "patient_external_id": patient_external_id,
                "status": status,
                "attachment_external_document_ids": attachment_external_document_ids,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                ChargeCapture,
                parse_obj_as(
                    type_=ChargeCapture,  # type: ignore
                    object_=_response_json,
                ),
            )
            return HttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnauthorizedErrorMessage,
                        parse_obj_as(
                            type_=UnauthorizedErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "HttpRequestValidationsError":
                raise HttpRequestValidationsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.List[RequestValidationError],
                        parse_obj_as(
                            type_=typing.List[RequestValidationError],  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "SchemaInstanceValidationHttpFailure":
                raise SchemaInstanceValidationHttpFailure(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        SchemaInstanceValidationFailure,
                        parse_obj_as(
                            type_=SchemaInstanceValidationFailure,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnprocessableEntityErrorMessage,
                        parse_obj_as(
                            type_=UnprocessableEntityErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "ChargeExternalIdConflictError":
                raise ChargeExternalIdConflictError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        ChargeExternalIdConflictErrorMessage,
                        parse_obj_as(
                            type_=ChargeExternalIdConflictErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def create_from_pre_encounter_patient(
        self,
        *,
        data: ChargeCaptureData,
        charge_external_id: str,
        pre_encounter_patient_id: PreEncounterPatientId,
        pre_encounter_appointment_ids: typing.Sequence[PreEncounterAppointmentId],
        status: ChargeCaptureStatus,
        originating_system: typing.Optional[str] = OMIT,
        claim_creation_category: typing.Optional[str] = OMIT,
        ehr_source_url: typing.Optional[str] = OMIT,
        attachment_external_document_ids: typing.Optional[typing.Sequence[str]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[ChargeCapture]:
        """
        Create a Charge Capture from a pre-encounter patient and appointment. This endpoint is intended to be used by consumers who are managing
        patients and appointments in the pre-encounter service and is currently under development. Consumers who are not taking advantage
        of the pre-encounter service should use the standard create endpoint.

        At encounter creation time, information from the provided patient and appointment objects will be populated
        where applicable. In particular, the following fields are populated from the patient and appointment objects:
          - Patient
          - Referring Provider
          - Subscriber Primary
          - Subscriber Secondary
          - Referral Number
          - Responsible Party
          - Guarantor

        Note that these fields should not be populated in the ChargeCaptureData property of this endpoint, as they will be overwritten at encounter creation time.

        Utilizing this endpoint opts you into automatic updating of the encounter when the patient or appointment is updated, assuming the
        encounter has not already been submitted or adjudicated.

        Parameters
        ----------
        data : ChargeCaptureData
            Charge Capture data contains all the fields needed to create an encounter, but listed as optional. Candid will use this data when attempting to bundle multiple Charge Captures into a single encounter.

        charge_external_id : str
            A client-specified unique ID to associate with this encounter; for example, your internal encounter ID or a Dr. Chrono encounter ID. This field should not contain PHI.

        pre_encounter_patient_id : PreEncounterPatientId

        pre_encounter_appointment_ids : typing.Sequence[PreEncounterAppointmentId]

        status : ChargeCaptureStatus
            the status of the charge capture

        originating_system : typing.Optional[str]
            An optional string field denoting the originating system of the charge.

        claim_creation_category : typing.Optional[str]
            An optional string field denoting the user defined category of the claim creation.

        ehr_source_url : typing.Optional[str]
            External URL reference that links to Charge Capture details within the external system (e.g. the EHR visit page). Send full URL format for the external link (e.g. https://emr_charge_capture_url.com/123).

        attachment_external_document_ids : typing.Optional[typing.Sequence[str]]
            Provide external attachment IDs which have been uploaded to Candid. They will be associated with the Encounter at Encounter creation time.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ChargeCapture]
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/charge_captures/v1/create-from-pre-encounter",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="POST",
            json={
                "data": data,
                "charge_external_id": charge_external_id,
                "pre_encounter_patient_id": pre_encounter_patient_id,
                "pre_encounter_appointment_ids": pre_encounter_appointment_ids,
                "originating_system": originating_system,
                "claim_creation_category": claim_creation_category,
                "ehr_source_url": ehr_source_url,
                "status": status,
                "attachment_external_document_ids": attachment_external_document_ids,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                ChargeCapture,
                parse_obj_as(
                    type_=ChargeCapture,  # type: ignore
                    object_=_response_json,
                ),
            )
            return HttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnauthorizedErrorMessage,
                        parse_obj_as(
                            type_=UnauthorizedErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "HttpRequestValidationsError":
                raise HttpRequestValidationsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.List[RequestValidationError],
                        parse_obj_as(
                            type_=typing.List[RequestValidationError],  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "SchemaInstanceValidationHttpFailure":
                raise SchemaInstanceValidationHttpFailure(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        SchemaInstanceValidationFailure,
                        parse_obj_as(
                            type_=SchemaInstanceValidationFailure,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnprocessableEntityErrorMessage,
                        parse_obj_as(
                            type_=UnprocessableEntityErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "ChargeExternalIdConflictError":
                raise ChargeExternalIdConflictError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        ChargeExternalIdConflictErrorMessage,
                        parse_obj_as(
                            type_=ChargeExternalIdConflictErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def update_post_billed_changes(
        self,
        *,
        charge_capture_change_ids: typing.Sequence[ChargeCapturePostBilledChangeId],
        resolved: bool,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[typing.List[ChargeCapturePostBilledChange]]:
        """
        Parameters
        ----------
        charge_capture_change_ids : typing.Sequence[ChargeCapturePostBilledChangeId]
            A list of UUIDs corresponding to ChargeCapturePostBilledChanges.
            All of the charges sent will be marked as resolved

        resolved : bool
            Whether the change has been resolved. If true, the change will be marked as resolved.
            If false, the change will be marked as unresolved.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[typing.List[ChargeCapturePostBilledChange]]
            This list of updates will always return at most 1 update that is not resolved. The singular update will contain the difference between the updated charge and the created encounter.
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/charge_captures/v1/changes",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="PATCH",
            json={
                "charge_capture_change_ids": charge_capture_change_ids,
                "resolved": resolved,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                typing.List[ChargeCapturePostBilledChange],
                parse_obj_as(
                    type_=typing.List[ChargeCapturePostBilledChange],  # type: ignore
                    object_=_response_json,
                ),
            )
            return HttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnauthorizedErrorMessage,
                        parse_obj_as(
                            type_=UnauthorizedErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def update(
        self,
        charge_capture_id: ChargeCaptureId,
        *,
        data: typing.Optional[ChargeCaptureData] = OMIT,
        charge_external_id: typing.Optional[str] = OMIT,
        ehr_source_url: typing.Optional[str] = OMIT,
        originating_system: typing.Optional[str] = OMIT,
        claim_creation_category: typing.Optional[str] = OMIT,
        patient_external_id: typing.Optional[str] = OMIT,
        status: typing.Optional[ChargeCaptureStatus] = OMIT,
        attachment_external_document_ids: typing.Optional[typing.Sequence[str]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[ChargeCapture]:
        """
        Parameters
        ----------
        charge_capture_id : ChargeCaptureId

        data : typing.Optional[ChargeCaptureData]

        charge_external_id : typing.Optional[str]
            A client-specified unique ID to associate with this encounter;
            for example, your internal encounter ID or a Dr. Chrono encounter ID.
            This field should not contain PHI.

        ehr_source_url : typing.Optional[str]
            External URL reference that links to Charge Capture details within the external system (e.g. the EHR visit page).
            Send full URL format for the external link (e.g. https://emr_charge_capture_url.com/123).

        originating_system : typing.Optional[str]
            An optional string field denoting the originating system of the charge.

        claim_creation_category : typing.Optional[str]
            An optional string field denoting the user defined category of the claim creation.

        patient_external_id : typing.Optional[str]
            The patient ID from the external EMR platform for the patient

        status : typing.Optional[ChargeCaptureStatus]
            the status of the charge capture

        attachment_external_document_ids : typing.Optional[typing.Sequence[str]]
            Provide external attachment IDs which have been uploaded to Candid. They will be associated with the Encounter at Encounter creation time.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ChargeCapture]
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/charge_captures/v1/{jsonable_encoder(charge_capture_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="PATCH",
            json={
                "data": data,
                "charge_external_id": charge_external_id,
                "ehr_source_url": ehr_source_url,
                "originating_system": originating_system,
                "claim_creation_category": claim_creation_category,
                "patient_external_id": patient_external_id,
                "status": status,
                "attachment_external_document_ids": attachment_external_document_ids,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                ChargeCapture,
                parse_obj_as(
                    type_=ChargeCapture,  # type: ignore
                    object_=_response_json,
                ),
            )
            return HttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnauthorizedErrorMessage,
                        parse_obj_as(
                            type_=UnauthorizedErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "HttpRequestValidationsError":
                raise HttpRequestValidationsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.List[RequestValidationError],
                        parse_obj_as(
                            type_=typing.List[RequestValidationError],  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "SchemaInstanceValidationHttpFailure":
                raise SchemaInstanceValidationHttpFailure(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        SchemaInstanceValidationFailure,
                        parse_obj_as(
                            type_=SchemaInstanceValidationFailure,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnprocessableEntityErrorMessage,
                        parse_obj_as(
                            type_=UnprocessableEntityErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get(
        self, charge_capture_id: ChargeCaptureId, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[ChargeCapture]:
        """
        Parameters
        ----------
        charge_capture_id : ChargeCaptureId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ChargeCapture]
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/charge_captures/v1/{jsonable_encoder(charge_capture_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="GET",
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                ChargeCapture,
                parse_obj_as(
                    type_=ChargeCapture,  # type: ignore
                    object_=_response_json,
                ),
            )
            return HttpResponse(response=_response, data=_data)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_all(
        self,
        *,
        limit: typing.Optional[int] = None,
        sort: typing.Optional[ChargeCaptureSortField] = None,
        sort_direction: typing.Optional[SortDirection] = None,
        page_token: typing.Optional[PageToken] = None,
        patient_external_id: typing.Optional[str] = None,
        status: typing.Optional[ChargeCaptureStatus] = None,
        charge_external_id: typing.Optional[str] = None,
        date_of_service_min: typing.Optional[dt.date] = None,
        date_of_service_max: typing.Optional[dt.date] = None,
        claim_ids: typing.Optional[typing.Union[EncounterId, typing.Sequence[EncounterId]]] = None,
        claim_creation_ids: typing.Optional[
            typing.Union[ChargeCaptureClaimCreationId, typing.Sequence[ChargeCaptureClaimCreationId]]
        ] = None,
        billing_provider_npis: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        service_facility_name: typing.Optional[str] = None,
        primary_payer_ids: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        rendering_provider_npis: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        rendering_provider_names: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        supervising_provider_npis: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        supervising_provider_names: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        claim_creation_category: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        tags: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        primary_payer_names: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        patient_names: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        exclude_charges_linked_to_claims: typing.Optional[bool] = None,
        patient_external_id_ranked_sort: typing.Optional[str] = None,
        status_ranked_sort: typing.Optional[ChargeCaptureStatus] = None,
        charge_external_id_ranked_sort: typing.Optional[str] = None,
        date_of_service_min_ranked_sort: typing.Optional[dt.date] = None,
        date_of_service_max_ranked_sort: typing.Optional[dt.date] = None,
        search_term: typing.Optional[str] = None,
        billable_status: typing.Optional[BillableStatusType] = None,
        responsible_party: typing.Optional[ResponsiblePartyType] = None,
        claim_ids_ranked_sort: typing.Optional[typing.Union[EncounterId, typing.Sequence[EncounterId]]] = None,
        claim_creation_ids_ranked_sort: typing.Optional[
            typing.Union[ChargeCaptureClaimCreationId, typing.Sequence[ChargeCaptureClaimCreationId]]
        ] = None,
        billing_provider_npis_ranked_sort: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        service_facility_name_ranked_sort: typing.Optional[str] = None,
        primary_payer_ids_ranked_sort: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        rendering_provider_npis_ranked_sort: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        rendering_provider_names_ranked_sort: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        supervising_provider_npis_ranked_sort: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        supervising_provider_names_ranked_sort: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        claim_status: typing.Optional[ClaimStatus] = None,
        claim_creation_category_ranked_sort: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        tags_ranked_sort: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        primary_payer_names_ranked_sort: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        patient_names_ranked_sort: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[ChargeCapturePage]:
        """
        Parameters
        ----------
        limit : typing.Optional[int]
            Maximum number of entities per page, defaults to 100.

        sort : typing.Optional[ChargeCaptureSortField]
            Defaults to created_at

        sort_direction : typing.Optional[SortDirection]
            Sort direction. Defaults to descending order if not provided.

        page_token : typing.Optional[PageToken]

        patient_external_id : typing.Optional[str]
            The patient ID from the external EMR platform for the patient

        status : typing.Optional[ChargeCaptureStatus]
            the status of the charge captures

        charge_external_id : typing.Optional[str]
            A client-specified unique ID to associate with this encounter;
            for example, your internal encounter ID or a Dr. Chrono encounter ID.
            This field should not contain PHI.

        date_of_service_min : typing.Optional[dt.date]
            Date formatted as YYYY-MM-DD; eg: 2019-08-24.
            This date must be the local date in the timezone where the service occurred.

        date_of_service_max : typing.Optional[dt.date]
            Date formatted as YYYY-MM-DD; eg: 2019-08-24.
            This date must be the local date in the timezone where the service occurred.

        claim_ids : typing.Optional[typing.Union[EncounterId, typing.Sequence[EncounterId]]]
            A list of claim IDs to filter by. This will return all charge captures that have a resulting claim with one of the IDs in this list.

        claim_creation_ids : typing.Optional[typing.Union[ChargeCaptureClaimCreationId, typing.Sequence[ChargeCaptureClaimCreationId]]]
            A list of Claim Creation IDs to filter by.

        billing_provider_npis : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of billing provider NPIs to filter by. This will return all charge captures with one of the NPIs in this list.

        service_facility_name : typing.Optional[str]
            A string to filter by. This will return all charge captures with this service facility name.

        primary_payer_ids : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of primary payer IDs to filter by. This will return all charge captures with one of the primary payer IDs in this list.

        rendering_provider_npis : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of rendering provider NPIs to filter by. This will return all charge captures with one of the NPIs in this list.

        rendering_provider_names : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of rendering provider names to filter by. This will return all charge captures with one of the names in this list.

        supervising_provider_npis : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of supervising provider NPIs to filter by. This will return all charge captures with one of the NPIs in this list.

        supervising_provider_names : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of supervising provider names to filter by. This will return all charge captures with one of the names in this list.

        claim_creation_category : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of claim creation categories to filter by. This will return all charge capture claim_creations which include one or more charges with one of the names in this list.

        tags : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of tags to filter by. This will return all charge captures with one of the tags.

        primary_payer_names : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of primary payer names to filter by. This will return all charge captures with one of the names.

        patient_names : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of patient names to filter by. This will return all charge captures with one of the names.

        exclude_charges_linked_to_claims : typing.Optional[bool]
            Whether to exclude charge captures which are part of a claim creation.

        patient_external_id_ranked_sort : typing.Optional[str]
            The patient ID from the external EMR platform for the patient

        status_ranked_sort : typing.Optional[ChargeCaptureStatus]
            The charge capture status to show first

        charge_external_id_ranked_sort : typing.Optional[str]
            A client-specified unique ID to associate with this encounter;
            for example, your internal encounter ID or a Dr. Chrono encounter ID.
            This field should not contain PHI.

        date_of_service_min_ranked_sort : typing.Optional[dt.date]
            Date formatted as YYYY-MM-DD; eg: 2019-08-24.
            This date must be the local date in the timezone where the service occurred.

        date_of_service_max_ranked_sort : typing.Optional[dt.date]
            Date formatted as YYYY-MM-DD; eg: 2019-08-24.
            This date must be the local date in the timezone where the service occurred.

        search_term : typing.Optional[str]
            Filter by any of the following fields: charge_id, claim_id, patient external_id,
            patient date of birth, patient first name, patient last name,
            or charge external id.

        billable_status : typing.Optional[BillableStatusType]
            Defines if the Encounter is to be billed by Candid to the responsible_party. Examples for when this should be set to NOT_BILLABLE include if the Encounter has not occurred yet or if there is no intention of ever billing the responsible_party.

        responsible_party : typing.Optional[ResponsiblePartyType]
            Defines the party to be billed with the initial balance owed on the claim. Use SELF_PAY if you intend to bill self pay/cash pay.

        claim_ids_ranked_sort : typing.Optional[typing.Union[EncounterId, typing.Sequence[EncounterId]]]
            A list of claim IDs to show first. This will return all charge captures that have a resulting claim with one of the IDs in this list.

        claim_creation_ids_ranked_sort : typing.Optional[typing.Union[ChargeCaptureClaimCreationId, typing.Sequence[ChargeCaptureClaimCreationId]]]
            A list of Claim Creation IDs to show first.

        billing_provider_npis_ranked_sort : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of billing provider NPIs to show first. This will return all charge captures with one of the NPIs in this list.

        service_facility_name_ranked_sort : typing.Optional[str]
            A string to show first. This will return all charge captures with this service facility name.

        primary_payer_ids_ranked_sort : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of primary payer IDs to show first. This will return all charge captures with one of the primary payer IDs in this list.

        rendering_provider_npis_ranked_sort : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of rendering provider NPIs to show first. This will return all charge captures with one of the NPIs in this list.

        rendering_provider_names_ranked_sort : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of rendering provider names to show first. This will return all charge captures with one of the names in this list.

        supervising_provider_npis_ranked_sort : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of supervising provider NPIs to show first. This will return all charge captures with one of the NPIs in this list.

        supervising_provider_names_ranked_sort : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of supervising provider names to show first. This will return all charge captures with one of the names in this list.

        claim_status : typing.Optional[ClaimStatus]
            the status of the claim to filter by created from charge capture bundle.

        claim_creation_category_ranked_sort : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of claim creation categories to sort by. This will return all charge capture claim_creations which include one or more charges with one of the names in this list.

        tags_ranked_sort : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of tags. This will return all charge captures with one of the tags.

        primary_payer_names_ranked_sort : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of primary payer names to sort by. This will return all charge captures with one of the names.

        patient_names_ranked_sort : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of patient names to sort by. This will return all charge captures with one of the names.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ChargeCapturePage]
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/charge_captures/v1",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="GET",
            params={
                "limit": limit,
                "sort": sort,
                "sort_direction": sort_direction,
                "page_token": page_token,
                "patient_external_id": patient_external_id,
                "status": status,
                "charge_external_id": charge_external_id,
                "date_of_service_min": str(date_of_service_min) if date_of_service_min is not None else None,
                "date_of_service_max": str(date_of_service_max) if date_of_service_max is not None else None,
                "claim_ids": claim_ids,
                "claim_creation_ids": claim_creation_ids,
                "billing_provider_npis": billing_provider_npis,
                "service_facility_name": service_facility_name,
                "primary_payer_ids": primary_payer_ids,
                "rendering_provider_npis": rendering_provider_npis,
                "rendering_provider_names": rendering_provider_names,
                "supervising_provider_npis": supervising_provider_npis,
                "supervising_provider_names": supervising_provider_names,
                "claim_creation_category": claim_creation_category,
                "tags": tags,
                "primary_payer_names": primary_payer_names,
                "patient_names": patient_names,
                "exclude_charges_linked_to_claims": exclude_charges_linked_to_claims,
                "patient_external_id_ranked_sort": patient_external_id_ranked_sort,
                "status_ranked_sort": status_ranked_sort,
                "charge_external_id_ranked_sort": charge_external_id_ranked_sort,
                "date_of_service_min_ranked_sort": str(date_of_service_min_ranked_sort)
                if date_of_service_min_ranked_sort is not None
                else None,
                "date_of_service_max_ranked_sort": str(date_of_service_max_ranked_sort)
                if date_of_service_max_ranked_sort is not None
                else None,
                "search_term": search_term,
                "billable_status": billable_status,
                "responsible_party": responsible_party,
                "claim_ids_ranked_sort": claim_ids_ranked_sort,
                "claim_creation_ids_ranked_sort": claim_creation_ids_ranked_sort,
                "billing_provider_npis_ranked_sort": billing_provider_npis_ranked_sort,
                "service_facility_name_ranked_sort": service_facility_name_ranked_sort,
                "primary_payer_ids_ranked_sort": primary_payer_ids_ranked_sort,
                "rendering_provider_npis_ranked_sort": rendering_provider_npis_ranked_sort,
                "rendering_provider_names_ranked_sort": rendering_provider_names_ranked_sort,
                "supervising_provider_npis_ranked_sort": supervising_provider_npis_ranked_sort,
                "supervising_provider_names_ranked_sort": supervising_provider_names_ranked_sort,
                "claim_status": claim_status,
                "claim_creation_category_ranked_sort": claim_creation_category_ranked_sort,
                "tags_ranked_sort": tags_ranked_sort,
                "primary_payer_names_ranked_sort": primary_payer_names_ranked_sort,
                "patient_names_ranked_sort": patient_names_ranked_sort,
            },
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                ChargeCapturePage,
                parse_obj_as(
                    type_=ChargeCapturePage,  # type: ignore
                    object_=_response_json,
                ),
            )
            return HttpResponse(response=_response, data=_data)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawV1Client:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def create(
        self,
        *,
        data: ChargeCaptureData,
        charge_external_id: str,
        patient_external_id: str,
        status: ChargeCaptureStatus,
        originating_system: typing.Optional[str] = OMIT,
        claim_creation_category: typing.Optional[str] = OMIT,
        ehr_source_url: typing.Optional[str] = OMIT,
        attachment_external_document_ids: typing.Optional[typing.Sequence[str]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[ChargeCapture]:
        """
        Parameters
        ----------
        data : ChargeCaptureData
            Charge Capture data contains all the fields needed to create an encounter, but listed as optional. Candid will use this data when attempting to bundle multiple Charge Captures into a single encounter.

        charge_external_id : str
            A client-specified unique ID to associate with this encounter; for example, your internal encounter ID or a Dr. Chrono encounter ID. This field should not contain PHI.

        patient_external_id : str
            The patient ID from the external EMR platform for the patient

        status : ChargeCaptureStatus
            the status of the charge capture

        originating_system : typing.Optional[str]
            An optional string field denoting the originating system of the charge.

        claim_creation_category : typing.Optional[str]
            An optional string field denoting the user defined category of the claim creation.

        ehr_source_url : typing.Optional[str]
            External URL reference that links to Charge Capture details within the external system (e.g. the EHR visit page). Send full URL format for the external link (e.g. https://emr_charge_capture_url.com/123).

        attachment_external_document_ids : typing.Optional[typing.Sequence[str]]
            Provide external attachment IDs which have been uploaded to Candid. They will be associated with the Encounter at Encounter creation time.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ChargeCapture]
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/charge_captures/v1",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="POST",
            json={
                "data": data,
                "charge_external_id": charge_external_id,
                "originating_system": originating_system,
                "claim_creation_category": claim_creation_category,
                "ehr_source_url": ehr_source_url,
                "patient_external_id": patient_external_id,
                "status": status,
                "attachment_external_document_ids": attachment_external_document_ids,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                ChargeCapture,
                parse_obj_as(
                    type_=ChargeCapture,  # type: ignore
                    object_=_response_json,
                ),
            )
            return AsyncHttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnauthorizedErrorMessage,
                        parse_obj_as(
                            type_=UnauthorizedErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "HttpRequestValidationsError":
                raise HttpRequestValidationsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.List[RequestValidationError],
                        parse_obj_as(
                            type_=typing.List[RequestValidationError],  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "SchemaInstanceValidationHttpFailure":
                raise SchemaInstanceValidationHttpFailure(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        SchemaInstanceValidationFailure,
                        parse_obj_as(
                            type_=SchemaInstanceValidationFailure,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnprocessableEntityErrorMessage,
                        parse_obj_as(
                            type_=UnprocessableEntityErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "ChargeExternalIdConflictError":
                raise ChargeExternalIdConflictError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        ChargeExternalIdConflictErrorMessage,
                        parse_obj_as(
                            type_=ChargeExternalIdConflictErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def create_from_pre_encounter_patient(
        self,
        *,
        data: ChargeCaptureData,
        charge_external_id: str,
        pre_encounter_patient_id: PreEncounterPatientId,
        pre_encounter_appointment_ids: typing.Sequence[PreEncounterAppointmentId],
        status: ChargeCaptureStatus,
        originating_system: typing.Optional[str] = OMIT,
        claim_creation_category: typing.Optional[str] = OMIT,
        ehr_source_url: typing.Optional[str] = OMIT,
        attachment_external_document_ids: typing.Optional[typing.Sequence[str]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[ChargeCapture]:
        """
        Create a Charge Capture from a pre-encounter patient and appointment. This endpoint is intended to be used by consumers who are managing
        patients and appointments in the pre-encounter service and is currently under development. Consumers who are not taking advantage
        of the pre-encounter service should use the standard create endpoint.

        At encounter creation time, information from the provided patient and appointment objects will be populated
        where applicable. In particular, the following fields are populated from the patient and appointment objects:
          - Patient
          - Referring Provider
          - Subscriber Primary
          - Subscriber Secondary
          - Referral Number
          - Responsible Party
          - Guarantor

        Note that these fields should not be populated in the ChargeCaptureData property of this endpoint, as they will be overwritten at encounter creation time.

        Utilizing this endpoint opts you into automatic updating of the encounter when the patient or appointment is updated, assuming the
        encounter has not already been submitted or adjudicated.

        Parameters
        ----------
        data : ChargeCaptureData
            Charge Capture data contains all the fields needed to create an encounter, but listed as optional. Candid will use this data when attempting to bundle multiple Charge Captures into a single encounter.

        charge_external_id : str
            A client-specified unique ID to associate with this encounter; for example, your internal encounter ID or a Dr. Chrono encounter ID. This field should not contain PHI.

        pre_encounter_patient_id : PreEncounterPatientId

        pre_encounter_appointment_ids : typing.Sequence[PreEncounterAppointmentId]

        status : ChargeCaptureStatus
            the status of the charge capture

        originating_system : typing.Optional[str]
            An optional string field denoting the originating system of the charge.

        claim_creation_category : typing.Optional[str]
            An optional string field denoting the user defined category of the claim creation.

        ehr_source_url : typing.Optional[str]
            External URL reference that links to Charge Capture details within the external system (e.g. the EHR visit page). Send full URL format for the external link (e.g. https://emr_charge_capture_url.com/123).

        attachment_external_document_ids : typing.Optional[typing.Sequence[str]]
            Provide external attachment IDs which have been uploaded to Candid. They will be associated with the Encounter at Encounter creation time.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ChargeCapture]
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/charge_captures/v1/create-from-pre-encounter",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="POST",
            json={
                "data": data,
                "charge_external_id": charge_external_id,
                "pre_encounter_patient_id": pre_encounter_patient_id,
                "pre_encounter_appointment_ids": pre_encounter_appointment_ids,
                "originating_system": originating_system,
                "claim_creation_category": claim_creation_category,
                "ehr_source_url": ehr_source_url,
                "status": status,
                "attachment_external_document_ids": attachment_external_document_ids,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                ChargeCapture,
                parse_obj_as(
                    type_=ChargeCapture,  # type: ignore
                    object_=_response_json,
                ),
            )
            return AsyncHttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnauthorizedErrorMessage,
                        parse_obj_as(
                            type_=UnauthorizedErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "HttpRequestValidationsError":
                raise HttpRequestValidationsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.List[RequestValidationError],
                        parse_obj_as(
                            type_=typing.List[RequestValidationError],  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "SchemaInstanceValidationHttpFailure":
                raise SchemaInstanceValidationHttpFailure(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        SchemaInstanceValidationFailure,
                        parse_obj_as(
                            type_=SchemaInstanceValidationFailure,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnprocessableEntityErrorMessage,
                        parse_obj_as(
                            type_=UnprocessableEntityErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "ChargeExternalIdConflictError":
                raise ChargeExternalIdConflictError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        ChargeExternalIdConflictErrorMessage,
                        parse_obj_as(
                            type_=ChargeExternalIdConflictErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def update_post_billed_changes(
        self,
        *,
        charge_capture_change_ids: typing.Sequence[ChargeCapturePostBilledChangeId],
        resolved: bool,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[typing.List[ChargeCapturePostBilledChange]]:
        """
        Parameters
        ----------
        charge_capture_change_ids : typing.Sequence[ChargeCapturePostBilledChangeId]
            A list of UUIDs corresponding to ChargeCapturePostBilledChanges.
            All of the charges sent will be marked as resolved

        resolved : bool
            Whether the change has been resolved. If true, the change will be marked as resolved.
            If false, the change will be marked as unresolved.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[typing.List[ChargeCapturePostBilledChange]]
            This list of updates will always return at most 1 update that is not resolved. The singular update will contain the difference between the updated charge and the created encounter.
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/charge_captures/v1/changes",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="PATCH",
            json={
                "charge_capture_change_ids": charge_capture_change_ids,
                "resolved": resolved,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                typing.List[ChargeCapturePostBilledChange],
                parse_obj_as(
                    type_=typing.List[ChargeCapturePostBilledChange],  # type: ignore
                    object_=_response_json,
                ),
            )
            return AsyncHttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnauthorizedErrorMessage,
                        parse_obj_as(
                            type_=UnauthorizedErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def update(
        self,
        charge_capture_id: ChargeCaptureId,
        *,
        data: typing.Optional[ChargeCaptureData] = OMIT,
        charge_external_id: typing.Optional[str] = OMIT,
        ehr_source_url: typing.Optional[str] = OMIT,
        originating_system: typing.Optional[str] = OMIT,
        claim_creation_category: typing.Optional[str] = OMIT,
        patient_external_id: typing.Optional[str] = OMIT,
        status: typing.Optional[ChargeCaptureStatus] = OMIT,
        attachment_external_document_ids: typing.Optional[typing.Sequence[str]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[ChargeCapture]:
        """
        Parameters
        ----------
        charge_capture_id : ChargeCaptureId

        data : typing.Optional[ChargeCaptureData]

        charge_external_id : typing.Optional[str]
            A client-specified unique ID to associate with this encounter;
            for example, your internal encounter ID or a Dr. Chrono encounter ID.
            This field should not contain PHI.

        ehr_source_url : typing.Optional[str]
            External URL reference that links to Charge Capture details within the external system (e.g. the EHR visit page).
            Send full URL format for the external link (e.g. https://emr_charge_capture_url.com/123).

        originating_system : typing.Optional[str]
            An optional string field denoting the originating system of the charge.

        claim_creation_category : typing.Optional[str]
            An optional string field denoting the user defined category of the claim creation.

        patient_external_id : typing.Optional[str]
            The patient ID from the external EMR platform for the patient

        status : typing.Optional[ChargeCaptureStatus]
            the status of the charge capture

        attachment_external_document_ids : typing.Optional[typing.Sequence[str]]
            Provide external attachment IDs which have been uploaded to Candid. They will be associated with the Encounter at Encounter creation time.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ChargeCapture]
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/charge_captures/v1/{jsonable_encoder(charge_capture_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="PATCH",
            json={
                "data": data,
                "charge_external_id": charge_external_id,
                "ehr_source_url": ehr_source_url,
                "originating_system": originating_system,
                "claim_creation_category": claim_creation_category,
                "patient_external_id": patient_external_id,
                "status": status,
                "attachment_external_document_ids": attachment_external_document_ids,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                ChargeCapture,
                parse_obj_as(
                    type_=ChargeCapture,  # type: ignore
                    object_=_response_json,
                ),
            )
            return AsyncHttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnauthorizedErrorMessage,
                        parse_obj_as(
                            type_=UnauthorizedErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "HttpRequestValidationsError":
                raise HttpRequestValidationsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.List[RequestValidationError],
                        parse_obj_as(
                            type_=typing.List[RequestValidationError],  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "SchemaInstanceValidationHttpFailure":
                raise SchemaInstanceValidationHttpFailure(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        SchemaInstanceValidationFailure,
                        parse_obj_as(
                            type_=SchemaInstanceValidationFailure,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnprocessableEntityErrorMessage,
                        parse_obj_as(
                            type_=UnprocessableEntityErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get(
        self, charge_capture_id: ChargeCaptureId, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[ChargeCapture]:
        """
        Parameters
        ----------
        charge_capture_id : ChargeCaptureId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ChargeCapture]
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/charge_captures/v1/{jsonable_encoder(charge_capture_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="GET",
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                ChargeCapture,
                parse_obj_as(
                    type_=ChargeCapture,  # type: ignore
                    object_=_response_json,
                ),
            )
            return AsyncHttpResponse(response=_response, data=_data)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_all(
        self,
        *,
        limit: typing.Optional[int] = None,
        sort: typing.Optional[ChargeCaptureSortField] = None,
        sort_direction: typing.Optional[SortDirection] = None,
        page_token: typing.Optional[PageToken] = None,
        patient_external_id: typing.Optional[str] = None,
        status: typing.Optional[ChargeCaptureStatus] = None,
        charge_external_id: typing.Optional[str] = None,
        date_of_service_min: typing.Optional[dt.date] = None,
        date_of_service_max: typing.Optional[dt.date] = None,
        claim_ids: typing.Optional[typing.Union[EncounterId, typing.Sequence[EncounterId]]] = None,
        claim_creation_ids: typing.Optional[
            typing.Union[ChargeCaptureClaimCreationId, typing.Sequence[ChargeCaptureClaimCreationId]]
        ] = None,
        billing_provider_npis: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        service_facility_name: typing.Optional[str] = None,
        primary_payer_ids: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        rendering_provider_npis: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        rendering_provider_names: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        supervising_provider_npis: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        supervising_provider_names: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        claim_creation_category: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        tags: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        primary_payer_names: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        patient_names: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        exclude_charges_linked_to_claims: typing.Optional[bool] = None,
        patient_external_id_ranked_sort: typing.Optional[str] = None,
        status_ranked_sort: typing.Optional[ChargeCaptureStatus] = None,
        charge_external_id_ranked_sort: typing.Optional[str] = None,
        date_of_service_min_ranked_sort: typing.Optional[dt.date] = None,
        date_of_service_max_ranked_sort: typing.Optional[dt.date] = None,
        search_term: typing.Optional[str] = None,
        billable_status: typing.Optional[BillableStatusType] = None,
        responsible_party: typing.Optional[ResponsiblePartyType] = None,
        claim_ids_ranked_sort: typing.Optional[typing.Union[EncounterId, typing.Sequence[EncounterId]]] = None,
        claim_creation_ids_ranked_sort: typing.Optional[
            typing.Union[ChargeCaptureClaimCreationId, typing.Sequence[ChargeCaptureClaimCreationId]]
        ] = None,
        billing_provider_npis_ranked_sort: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        service_facility_name_ranked_sort: typing.Optional[str] = None,
        primary_payer_ids_ranked_sort: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        rendering_provider_npis_ranked_sort: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        rendering_provider_names_ranked_sort: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        supervising_provider_npis_ranked_sort: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        supervising_provider_names_ranked_sort: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        claim_status: typing.Optional[ClaimStatus] = None,
        claim_creation_category_ranked_sort: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        tags_ranked_sort: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        primary_payer_names_ranked_sort: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        patient_names_ranked_sort: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[ChargeCapturePage]:
        """
        Parameters
        ----------
        limit : typing.Optional[int]
            Maximum number of entities per page, defaults to 100.

        sort : typing.Optional[ChargeCaptureSortField]
            Defaults to created_at

        sort_direction : typing.Optional[SortDirection]
            Sort direction. Defaults to descending order if not provided.

        page_token : typing.Optional[PageToken]

        patient_external_id : typing.Optional[str]
            The patient ID from the external EMR platform for the patient

        status : typing.Optional[ChargeCaptureStatus]
            the status of the charge captures

        charge_external_id : typing.Optional[str]
            A client-specified unique ID to associate with this encounter;
            for example, your internal encounter ID or a Dr. Chrono encounter ID.
            This field should not contain PHI.

        date_of_service_min : typing.Optional[dt.date]
            Date formatted as YYYY-MM-DD; eg: 2019-08-24.
            This date must be the local date in the timezone where the service occurred.

        date_of_service_max : typing.Optional[dt.date]
            Date formatted as YYYY-MM-DD; eg: 2019-08-24.
            This date must be the local date in the timezone where the service occurred.

        claim_ids : typing.Optional[typing.Union[EncounterId, typing.Sequence[EncounterId]]]
            A list of claim IDs to filter by. This will return all charge captures that have a resulting claim with one of the IDs in this list.

        claim_creation_ids : typing.Optional[typing.Union[ChargeCaptureClaimCreationId, typing.Sequence[ChargeCaptureClaimCreationId]]]
            A list of Claim Creation IDs to filter by.

        billing_provider_npis : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of billing provider NPIs to filter by. This will return all charge captures with one of the NPIs in this list.

        service_facility_name : typing.Optional[str]
            A string to filter by. This will return all charge captures with this service facility name.

        primary_payer_ids : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of primary payer IDs to filter by. This will return all charge captures with one of the primary payer IDs in this list.

        rendering_provider_npis : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of rendering provider NPIs to filter by. This will return all charge captures with one of the NPIs in this list.

        rendering_provider_names : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of rendering provider names to filter by. This will return all charge captures with one of the names in this list.

        supervising_provider_npis : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of supervising provider NPIs to filter by. This will return all charge captures with one of the NPIs in this list.

        supervising_provider_names : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of supervising provider names to filter by. This will return all charge captures with one of the names in this list.

        claim_creation_category : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of claim creation categories to filter by. This will return all charge capture claim_creations which include one or more charges with one of the names in this list.

        tags : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of tags to filter by. This will return all charge captures with one of the tags.

        primary_payer_names : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of primary payer names to filter by. This will return all charge captures with one of the names.

        patient_names : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of patient names to filter by. This will return all charge captures with one of the names.

        exclude_charges_linked_to_claims : typing.Optional[bool]
            Whether to exclude charge captures which are part of a claim creation.

        patient_external_id_ranked_sort : typing.Optional[str]
            The patient ID from the external EMR platform for the patient

        status_ranked_sort : typing.Optional[ChargeCaptureStatus]
            The charge capture status to show first

        charge_external_id_ranked_sort : typing.Optional[str]
            A client-specified unique ID to associate with this encounter;
            for example, your internal encounter ID or a Dr. Chrono encounter ID.
            This field should not contain PHI.

        date_of_service_min_ranked_sort : typing.Optional[dt.date]
            Date formatted as YYYY-MM-DD; eg: 2019-08-24.
            This date must be the local date in the timezone where the service occurred.

        date_of_service_max_ranked_sort : typing.Optional[dt.date]
            Date formatted as YYYY-MM-DD; eg: 2019-08-24.
            This date must be the local date in the timezone where the service occurred.

        search_term : typing.Optional[str]
            Filter by any of the following fields: charge_id, claim_id, patient external_id,
            patient date of birth, patient first name, patient last name,
            or charge external id.

        billable_status : typing.Optional[BillableStatusType]
            Defines if the Encounter is to be billed by Candid to the responsible_party. Examples for when this should be set to NOT_BILLABLE include if the Encounter has not occurred yet or if there is no intention of ever billing the responsible_party.

        responsible_party : typing.Optional[ResponsiblePartyType]
            Defines the party to be billed with the initial balance owed on the claim. Use SELF_PAY if you intend to bill self pay/cash pay.

        claim_ids_ranked_sort : typing.Optional[typing.Union[EncounterId, typing.Sequence[EncounterId]]]
            A list of claim IDs to show first. This will return all charge captures that have a resulting claim with one of the IDs in this list.

        claim_creation_ids_ranked_sort : typing.Optional[typing.Union[ChargeCaptureClaimCreationId, typing.Sequence[ChargeCaptureClaimCreationId]]]
            A list of Claim Creation IDs to show first.

        billing_provider_npis_ranked_sort : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of billing provider NPIs to show first. This will return all charge captures with one of the NPIs in this list.

        service_facility_name_ranked_sort : typing.Optional[str]
            A string to show first. This will return all charge captures with this service facility name.

        primary_payer_ids_ranked_sort : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of primary payer IDs to show first. This will return all charge captures with one of the primary payer IDs in this list.

        rendering_provider_npis_ranked_sort : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of rendering provider NPIs to show first. This will return all charge captures with one of the NPIs in this list.

        rendering_provider_names_ranked_sort : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of rendering provider names to show first. This will return all charge captures with one of the names in this list.

        supervising_provider_npis_ranked_sort : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of supervising provider NPIs to show first. This will return all charge captures with one of the NPIs in this list.

        supervising_provider_names_ranked_sort : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of supervising provider names to show first. This will return all charge captures with one of the names in this list.

        claim_status : typing.Optional[ClaimStatus]
            the status of the claim to filter by created from charge capture bundle.

        claim_creation_category_ranked_sort : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of claim creation categories to sort by. This will return all charge capture claim_creations which include one or more charges with one of the names in this list.

        tags_ranked_sort : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of tags. This will return all charge captures with one of the tags.

        primary_payer_names_ranked_sort : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of primary payer names to sort by. This will return all charge captures with one of the names.

        patient_names_ranked_sort : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of patient names to sort by. This will return all charge captures with one of the names.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ChargeCapturePage]
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/charge_captures/v1",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="GET",
            params={
                "limit": limit,
                "sort": sort,
                "sort_direction": sort_direction,
                "page_token": page_token,
                "patient_external_id": patient_external_id,
                "status": status,
                "charge_external_id": charge_external_id,
                "date_of_service_min": str(date_of_service_min) if date_of_service_min is not None else None,
                "date_of_service_max": str(date_of_service_max) if date_of_service_max is not None else None,
                "claim_ids": claim_ids,
                "claim_creation_ids": claim_creation_ids,
                "billing_provider_npis": billing_provider_npis,
                "service_facility_name": service_facility_name,
                "primary_payer_ids": primary_payer_ids,
                "rendering_provider_npis": rendering_provider_npis,
                "rendering_provider_names": rendering_provider_names,
                "supervising_provider_npis": supervising_provider_npis,
                "supervising_provider_names": supervising_provider_names,
                "claim_creation_category": claim_creation_category,
                "tags": tags,
                "primary_payer_names": primary_payer_names,
                "patient_names": patient_names,
                "exclude_charges_linked_to_claims": exclude_charges_linked_to_claims,
                "patient_external_id_ranked_sort": patient_external_id_ranked_sort,
                "status_ranked_sort": status_ranked_sort,
                "charge_external_id_ranked_sort": charge_external_id_ranked_sort,
                "date_of_service_min_ranked_sort": str(date_of_service_min_ranked_sort)
                if date_of_service_min_ranked_sort is not None
                else None,
                "date_of_service_max_ranked_sort": str(date_of_service_max_ranked_sort)
                if date_of_service_max_ranked_sort is not None
                else None,
                "search_term": search_term,
                "billable_status": billable_status,
                "responsible_party": responsible_party,
                "claim_ids_ranked_sort": claim_ids_ranked_sort,
                "claim_creation_ids_ranked_sort": claim_creation_ids_ranked_sort,
                "billing_provider_npis_ranked_sort": billing_provider_npis_ranked_sort,
                "service_facility_name_ranked_sort": service_facility_name_ranked_sort,
                "primary_payer_ids_ranked_sort": primary_payer_ids_ranked_sort,
                "rendering_provider_npis_ranked_sort": rendering_provider_npis_ranked_sort,
                "rendering_provider_names_ranked_sort": rendering_provider_names_ranked_sort,
                "supervising_provider_npis_ranked_sort": supervising_provider_npis_ranked_sort,
                "supervising_provider_names_ranked_sort": supervising_provider_names_ranked_sort,
                "claim_status": claim_status,
                "claim_creation_category_ranked_sort": claim_creation_category_ranked_sort,
                "tags_ranked_sort": tags_ranked_sort,
                "primary_payer_names_ranked_sort": primary_payer_names_ranked_sort,
                "patient_names_ranked_sort": patient_names_ranked_sort,
            },
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                ChargeCapturePage,
                parse_obj_as(
                    type_=ChargeCapturePage,  # type: ignore
                    object_=_response_json,
                ),
            )
            return AsyncHttpResponse(response=_response, data=_data)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import datetime as dt
import typing

import pydantic
import typing_extensions
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....commons.types.claim_id import ClaimId
from .....commons.types.patient_external_id import PatientExternalId
from .....commons.types.service_line_id import ServiceLineId
from .....non_insurance_payers.resources.v_1.types.non_insurance_payer import NonInsurancePayer
from .....payers.resources.v_3.types.payer import Payer
from .insurance_write_off_reason import InsuranceWriteOffReason
from .insurance_write_off_target import InsuranceWriteOffTarget
from .patient_write_off_reason import PatientWriteOffReason
from .write_off_id import WriteOffId


class WriteOff_Patient(UniversalBaseModel):
    type: typing.Literal["patient"] = "patient"
    write_off_id: WriteOffId
    write_off_timestamp: dt.datetime
    write_off_note: typing.Optional[str] = None
    write_off_reason: PatientWriteOffReason
    patient_external_id: PatientExternalId
    claim_id: ClaimId
    service_line_id: ServiceLineId
    reverts_write_off_id: typing.Optional[WriteOffId] = None
    reverted_by_write_off_id: typing.Optional[WriteOffId] = None
    amount_cents: int

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WriteOff_Insurance(UniversalBaseModel):
    type: typing.Literal["insurance"] = "insurance"
    write_off_id: WriteOffId
    payer: Payer
    write_off_target: InsuranceWriteOffTarget
    write_off_timestamp: dt.datetime
    write_off_note: typing.Optional[str] = None
    write_off_reason: InsuranceWriteOffReason
    reverts_write_off_id: typing.Optional[WriteOffId] = None
    reverted_by_write_off_id: typing.Optional[WriteOffId] = None
    amount_cents: int

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WriteOff_NonInsurancePayer(UniversalBaseModel):
    type: typing.Literal["non_insurance_payer"] = "non_insurance_payer"
    write_off_id: WriteOffId
    non_insurance_payer: NonInsurancePayer
    service_line_id: ServiceLineId
    write_off_timestamp: dt.datetime
    write_off_note: typing.Optional[str] = None
    write_off_reason: InsuranceWriteOffReason
    reverts_write_off_id: typing.Optional[WriteOffId] = None
    reverted_by_write_off_id: typing.Optional[WriteOffId] = None
    amount_cents: int

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


WriteOff = typing_extensions.Annotated[
    typing.Union[WriteOff_Patient, WriteOff_Insurance, WriteOff_NonInsurancePayer], pydantic.Field(discriminator="type")
]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .dimension_match import DimensionMatch
    from .dimension_name import DimensionName
    from .dimensions import Dimensions
    from .dimensions_page import DimensionsPage
    from .match_cpt_code import MatchCptCode
    from .match_date import MatchDate
    from .match_facility_type_code import MatchFacilityTypeCode
    from .match_geo import MatchGeo
    from .match_license_type import MatchLicenseType
    from .match_modifiers import MatchModifiers
    from .match_network_types import MatchNetworkTypes
    from .match_payer import MatchPayer
    from .match_payer_plan_groups import MatchPayerPlanGroups
    from .match_provider import MatchProvider
    from .match_result import MatchResult
    from .match_test_result import MatchTestResult
    from .new_rate import NewRate
    from .new_rate_version import NewRateVersion
    from .optional_dimensions import OptionalDimensions
    from .overlapping_rate_entries_error import OverlappingRateEntriesError
    from .payer_plan_group_does_not_match_rate_payer_error import PayerPlanGroupDoesNotMatchRatePayerError
    from .payer_threshold import PayerThreshold
    from .payer_thresholds_page import PayerThresholdsPage
    from .rate import Rate
    from .rate_entry import RateEntry
    from .rate_upload import RateUpload, RateUpload_NewRate, RateUpload_NewVersion
    from .rate_upload_with_possible_errors import RateUploadWithPossibleErrors
    from .rates_page import RatesPage
    from .threshold_match import ThresholdMatch
    from .validation_error import (
        ValidationError,
        ValidationError_DuplicateRate,
        ValidationError_EmptyEntries,
        ValidationError_OrganizationProviderNotFound,
        ValidationError_OverlappingRateEntries,
        ValidationError_PayerPlanGroupDoesNotMatchRatePayer,
        ValidationError_PayerPlanGroupNetworkTypeMutualExclusion,
        ValidationError_PayerPlanGroupNotFound,
        ValidationError_VersionConflict,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "DimensionMatch": ".dimension_match",
    "DimensionName": ".dimension_name",
    "Dimensions": ".dimensions",
    "DimensionsPage": ".dimensions_page",
    "MatchCptCode": ".match_cpt_code",
    "MatchDate": ".match_date",
    "MatchFacilityTypeCode": ".match_facility_type_code",
    "MatchGeo": ".match_geo",
    "MatchLicenseType": ".match_license_type",
    "MatchModifiers": ".match_modifiers",
    "MatchNetworkTypes": ".match_network_types",
    "MatchPayer": ".match_payer",
    "MatchPayerPlanGroups": ".match_payer_plan_groups",
    "MatchProvider": ".match_provider",
    "MatchResult": ".match_result",
    "MatchTestResult": ".match_test_result",
    "NewRate": ".new_rate",
    "NewRateVersion": ".new_rate_version",
    "OptionalDimensions": ".optional_dimensions",
    "OverlappingRateEntriesError": ".overlapping_rate_entries_error",
    "PayerPlanGroupDoesNotMatchRatePayerError": ".payer_plan_group_does_not_match_rate_payer_error",
    "PayerThreshold": ".payer_threshold",
    "PayerThresholdsPage": ".payer_thresholds_page",
    "Rate": ".rate",
    "RateEntry": ".rate_entry",
    "RateUpload": ".rate_upload",
    "RateUploadWithPossibleErrors": ".rate_upload_with_possible_errors",
    "RateUpload_NewRate": ".rate_upload",
    "RateUpload_NewVersion": ".rate_upload",
    "RatesPage": ".rates_page",
    "ThresholdMatch": ".threshold_match",
    "ValidationError": ".validation_error",
    "ValidationError_DuplicateRate": ".validation_error",
    "ValidationError_EmptyEntries": ".validation_error",
    "ValidationError_OrganizationProviderNotFound": ".validation_error",
    "ValidationError_OverlappingRateEntries": ".validation_error",
    "ValidationError_PayerPlanGroupDoesNotMatchRatePayer": ".validation_error",
    "ValidationError_PayerPlanGroupNetworkTypeMutualExclusion": ".validation_error",
    "ValidationError_PayerPlanGroupNotFound": ".validation_error",
    "ValidationError_VersionConflict": ".validation_error",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "DimensionMatch",
    "DimensionName",
    "Dimensions",
    "DimensionsPage",
    "MatchCptCode",
    "MatchDate",
    "MatchFacilityTypeCode",
    "MatchGeo",
    "MatchLicenseType",
    "MatchModifiers",
    "MatchNetworkTypes",
    "MatchPayer",
    "MatchPayerPlanGroups",
    "MatchProvider",
    "MatchResult",
    "MatchTestResult",
    "NewRate",
    "NewRateVersion",
    "OptionalDimensions",
    "OverlappingRateEntriesError",
    "PayerPlanGroupDoesNotMatchRatePayerError",
    "PayerThreshold",
    "PayerThresholdsPage",
    "Rate",
    "RateEntry",
    "RateUpload",
    "RateUploadWithPossibleErrors",
    "RateUpload_NewRate",
    "RateUpload_NewVersion",
    "RatesPage",
    "ThresholdMatch",
    "ValidationError",
    "ValidationError_DuplicateRate",
    "ValidationError_EmptyEntries",
    "ValidationError_OrganizationProviderNotFound",
    "ValidationError_OverlappingRateEntries",
    "ValidationError_PayerPlanGroupDoesNotMatchRatePayer",
    "ValidationError_PayerPlanGroupNetworkTypeMutualExclusion",
    "ValidationError_PayerPlanGroupNotFound",
    "ValidationError_VersionConflict",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2
from .d_8_date import D8Date
from .health_care_code_information_new import HealthCareCodeInformationNew
from .icd_code import IcdCode
from .other_procedure_information_code_qualifier import OtherProcedureInformationCodeQualifier


class OtherProcedureInformationNew(HealthCareCodeInformationNew):
    """
    This corresponds to the BBQ or BQ code qualifier values.
    """

    other_procedure_code_qualifier: OtherProcedureInformationCodeQualifier
    other_procedure_code: IcdCode
    other_procedure_date: D8Date = pydantic.Field()
    """
    An [RFC 3339, section 5.6 datetime](https://ijmacd.github.io/rfc3339-iso8601/).
    For example, 2017-07-21T17:32:28Z.
    In practice, only the date portion of this is used for claim submission, so
    midnight time is fine.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .additional_payer_information import AdditionalPayerInformation
    from .address import Address
    from .address_use import AddressUse
    from .appointment_id import AppointmentId
    from .base_model import BaseModel
    from .canonical_clinical_trial_association import CanonicalClinicalTrialAssociation
    from .canonical_clinical_trial_id import CanonicalClinicalTrialId
    from .canonical_non_insurance_payer_association import CanonicalNonInsurancePayerAssociation
    from .canonical_non_insurance_payer_id import CanonicalNonInsurancePayerId
    from .canonical_provider_id import CanonicalProviderId
    from .canonical_service_facility_id import CanonicalServiceFacilityId
    from .contact_point import ContactPoint
    from .contact_point_use import ContactPointUse
    from .coverage_id import CoverageId
    from .disability_status import DisabilityStatus
    from .error_base_4_xx import ErrorBase4Xx
    from .ethnicity import Ethnicity
    from .external_identifier import ExternalIdentifier
    from .external_provider import ExternalProvider
    from .external_provider_type import ExternalProviderType
    from .filter_query_string import FilterQueryString
    from .gender import Gender
    from .human_name import HumanName
    from .name_use import NameUse
    from .note_id import NoteId
    from .organization_id import OrganizationId
    from .page_token import PageToken
    from .patient_id import PatientId
    from .patient_service_facility import PatientServiceFacility
    from .payer_id import PayerId
    from .payer_plan_group_id import PayerPlanGroupId
    from .period import Period
    from .race import Race
    from .relationship import Relationship
    from .resource_page import ResourcePage
    from .sex import Sex
    from .sexual_orientation import SexualOrientation
    from .sort_direction import SortDirection
    from .tag_id import TagId
    from .user_id import UserId
    from .version_conflict_error_body import VersionConflictErrorBody
_dynamic_imports: typing.Dict[str, str] = {
    "AdditionalPayerInformation": ".additional_payer_information",
    "Address": ".address",
    "AddressUse": ".address_use",
    "AppointmentId": ".appointment_id",
    "BaseModel": ".base_model",
    "CanonicalClinicalTrialAssociation": ".canonical_clinical_trial_association",
    "CanonicalClinicalTrialId": ".canonical_clinical_trial_id",
    "CanonicalNonInsurancePayerAssociation": ".canonical_non_insurance_payer_association",
    "CanonicalNonInsurancePayerId": ".canonical_non_insurance_payer_id",
    "CanonicalProviderId": ".canonical_provider_id",
    "CanonicalServiceFacilityId": ".canonical_service_facility_id",
    "ContactPoint": ".contact_point",
    "ContactPointUse": ".contact_point_use",
    "CoverageId": ".coverage_id",
    "DisabilityStatus": ".disability_status",
    "ErrorBase4Xx": ".error_base_4_xx",
    "Ethnicity": ".ethnicity",
    "ExternalIdentifier": ".external_identifier",
    "ExternalProvider": ".external_provider",
    "ExternalProviderType": ".external_provider_type",
    "FilterQueryString": ".filter_query_string",
    "Gender": ".gender",
    "HumanName": ".human_name",
    "NameUse": ".name_use",
    "NoteId": ".note_id",
    "OrganizationId": ".organization_id",
    "PageToken": ".page_token",
    "PatientId": ".patient_id",
    "PatientServiceFacility": ".patient_service_facility",
    "PayerId": ".payer_id",
    "PayerPlanGroupId": ".payer_plan_group_id",
    "Period": ".period",
    "Race": ".race",
    "Relationship": ".relationship",
    "ResourcePage": ".resource_page",
    "Sex": ".sex",
    "SexualOrientation": ".sexual_orientation",
    "SortDirection": ".sort_direction",
    "TagId": ".tag_id",
    "UserId": ".user_id",
    "VersionConflictErrorBody": ".version_conflict_error_body",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "AdditionalPayerInformation",
    "Address",
    "AddressUse",
    "AppointmentId",
    "BaseModel",
    "CanonicalClinicalTrialAssociation",
    "CanonicalClinicalTrialId",
    "CanonicalNonInsurancePayerAssociation",
    "CanonicalNonInsurancePayerId",
    "CanonicalProviderId",
    "CanonicalServiceFacilityId",
    "ContactPoint",
    "ContactPointUse",
    "CoverageId",
    "DisabilityStatus",
    "ErrorBase4Xx",
    "Ethnicity",
    "ExternalIdentifier",
    "ExternalProvider",
    "ExternalProviderType",
    "FilterQueryString",
    "Gender",
    "HumanName",
    "NameUse",
    "NoteId",
    "OrganizationId",
    "PageToken",
    "PatientId",
    "PatientServiceFacility",
    "PayerId",
    "PayerPlanGroupId",
    "Period",
    "Race",
    "Relationship",
    "ResourcePage",
    "Sex",
    "SexualOrientation",
    "SortDirection",
    "TagId",
    "UserId",
    "VersionConflictErrorBody",
]



# This file was auto-generated by Fern from our API Definition.

import typing

from ......core import enum

T_Result = typing.TypeVar("T_Result")


class ContractStatus(enum.StrEnum):
    PENDING = "pending"
    """
    Contract is still in the works and has not been signed and counter-signed yet
    """

    EFFECTIVE = "effective"
    """
    Contract is active and in effect (claims will need to
    be submitted under effective contracts)
    """

    CANCELLED = "cancelled"
    """
    Contract is no longer effective but kept around for historical documentation
    """

    _UNKNOWN = "__CONTRACTSTATUS_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "ContractStatus":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        pending: typing.Callable[[], T_Result],
        effective: typing.Callable[[], T_Result],
        cancelled: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is ContractStatus.PENDING:
            return pending()
        if self is ContractStatus.EFFECTIVE:
            return effective()
        if self is ContractStatus.CANCELLED:
            return cancelled()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        CreateWriteOffsResponse,
        InsuranceWriteOff,
        InsuranceWriteOffCreate,
        InsuranceWriteOffReason,
        InsuranceWriteOffTarget,
        InsuranceWriteOffTarget_BillingProviderId,
        InsuranceWriteOffTarget_ClaimId,
        InsuranceWriteOffTarget_ServiceLineId,
        NonInsurancePayerWriteOff,
        NonInsurancePayerWriteOffCreate,
        PatientWriteOff,
        PatientWriteOffCreate,
        PatientWriteOffReason,
        WriteOff,
        WriteOffCreate,
        WriteOffCreate_Insurance,
        WriteOffCreate_NonInsurancePayer,
        WriteOffCreate_Patient,
        WriteOffId,
        WriteOffSortField,
        WriteOff_Insurance,
        WriteOff_NonInsurancePayer,
        WriteOff_Patient,
        WriteOffsPage,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "CreateWriteOffsResponse": ".types",
    "InsuranceWriteOff": ".types",
    "InsuranceWriteOffCreate": ".types",
    "InsuranceWriteOffReason": ".types",
    "InsuranceWriteOffTarget": ".types",
    "InsuranceWriteOffTarget_BillingProviderId": ".types",
    "InsuranceWriteOffTarget_ClaimId": ".types",
    "InsuranceWriteOffTarget_ServiceLineId": ".types",
    "NonInsurancePayerWriteOff": ".types",
    "NonInsurancePayerWriteOffCreate": ".types",
    "PatientWriteOff": ".types",
    "PatientWriteOffCreate": ".types",
    "PatientWriteOffReason": ".types",
    "WriteOff": ".types",
    "WriteOffCreate": ".types",
    "WriteOffCreate_Insurance": ".types",
    "WriteOffCreate_NonInsurancePayer": ".types",
    "WriteOffCreate_Patient": ".types",
    "WriteOffId": ".types",
    "WriteOffSortField": ".types",
    "WriteOff_Insurance": ".types",
    "WriteOff_NonInsurancePayer": ".types",
    "WriteOff_Patient": ".types",
    "WriteOffsPage": ".types",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "CreateWriteOffsResponse",
    "InsuranceWriteOff",
    "InsuranceWriteOffCreate",
    "InsuranceWriteOffReason",
    "InsuranceWriteOffTarget",
    "InsuranceWriteOffTarget_BillingProviderId",
    "InsuranceWriteOffTarget_ClaimId",
    "InsuranceWriteOffTarget_ServiceLineId",
    "NonInsurancePayerWriteOff",
    "NonInsurancePayerWriteOffCreate",
    "PatientWriteOff",
    "PatientWriteOffCreate",
    "PatientWriteOffReason",
    "WriteOff",
    "WriteOffCreate",
    "WriteOffCreate_Insurance",
    "WriteOffCreate_NonInsurancePayer",
    "WriteOffCreate_Patient",
    "WriteOffId",
    "WriteOffSortField",
    "WriteOff_Insurance",
    "WriteOff_NonInsurancePayer",
    "WriteOff_Patient",
    "WriteOffsPage",
]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....commons.types.encounter_external_id import EncounterExternalId
from .....commons.types.organization_id import OrganizationId
from .....commons.types.patient_external_id import PatientExternalId
from .....commons.types.service_line_id import ServiceLineId
from .patient_payment_id import PatientPaymentId
from .patient_payment_source import PatientPaymentSource
from .patient_payment_status import PatientPaymentStatus


class PatientPayment(UniversalBaseModel):
    """
    Examples
    --------
    import datetime
    import uuid

    from candid.resources.patient_payments.resources.v_3 import (
        PatientPayment,
        PatientPaymentSource,
        PatientPaymentStatus,
    )

    PatientPayment(
        patient_payment_id="CF237BE1-E793-4BBF-8958-61D5179D1D0D",
        organization_id=uuid.UUID(
            "0788ca2a-b20d-4b8e-b8d4-07fa0b3b4907",
        ),
        source_internal_id="D1A76039-D5C5-4323-A2FC-B7C8B6AEF6A4",
        source=PatientPaymentSource.MANUAL_ENTRY,
        amount_cents=2000,
        payment_timestamp=datetime.datetime.fromisoformat(
            "2023-01-01 00:00:00+00:00",
        ),
        status=PatientPaymentStatus.PENDING,
        payment_name="John Doe",
        payment_note="test payment note",
        patient_external_id="B7437260-D6B4-48CF-B9D7-753C09F34E76",
        encounter_external_id="0F26B9C3-199F-4CBB-A166-B87EA7C631BB",
        service_line_id=uuid.UUID(
            "b557dc86-c629-478c-850a-02d45ac11783",
        ),
    )
    """

    patient_payment_id: PatientPaymentId
    organization_id: OrganizationId
    source_internal_id: str
    source: PatientPaymentSource
    amount_cents: int
    payment_timestamp: typing.Optional[dt.datetime] = None
    status: typing.Optional[PatientPaymentStatus] = None
    payment_name: typing.Optional[str] = None
    payment_note: typing.Optional[str] = None
    patient_external_id: typing.Optional[PatientExternalId] = None
    encounter_external_id: typing.Optional[EncounterExternalId] = None
    service_line_id: typing.Optional[ServiceLineId] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....clinical_trials.resources.v_1.types.mutable_clinical_trial import MutableClinicalTrial
from .....commons.types.street_address_short_zip import StreetAddressShortZip


class CreateNonInsurancePayerRequest(UniversalBaseModel):
    name: str = pydantic.Field()
    """
    Max 50 characters allowed
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Max 255 characters allowed
    """

    category: typing.Optional[str] = pydantic.Field(default=None)
    """
    Max 255 characters allowed
    """

    address: typing.Optional[StreetAddressShortZip] = None
    clinical_trials: typing.Optional[typing.List[MutableClinicalTrial]] = pydantic.Field(default=None)
    """
    The same name cannot be used across several clinical trials
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2
from .....commons.types.decimal import Decimal
from .health_care_code_information_new import HealthCareCodeInformationNew
from .value_code import ValueCode
from .value_code_qualifier import ValueCodeQualifier


class ValueInformationNew(HealthCareCodeInformationNew):
    """
    This corresponds to the BE code qualifier value.
    """

    value_code_qualifier: ValueCodeQualifier
    value_code: ValueCode
    value_code_amount: Decimal

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ......core import enum

T_Result = typing.TypeVar("T_Result")


class PayerPlanGroupSortField(enum.StrEnum):
    PLAN_GROUP_NAME = "plan_group_name"
    PLAN_TYPE = "plan_type"
    CREATED_AT = "created_at"
    _UNKNOWN = "__PAYERPLANGROUPSORTFIELD_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "PayerPlanGroupSortField":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        plan_group_name: typing.Callable[[], T_Result],
        plan_type: typing.Callable[[], T_Result],
        created_at: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is PayerPlanGroupSortField.PLAN_GROUP_NAME:
            return plan_group_name()
        if self is PayerPlanGroupSortField.PLAN_TYPE:
            return plan_type()
        if self is PayerPlanGroupSortField.CREATED_AT:
            return created_at()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import typing

from ......core import enum

T_Result = typing.TypeVar("T_Result")


class AttachmentInclusion(enum.StrEnum):
    NOT_INCLUDED = "not_included"
    INCLUDED_ON_NEXT_SUBMISSION = "included_on_next_submission"
    INCLUDED_ON_ALL_SUBMISSIONS = "included_on_all_submissions"
    _UNKNOWN = "__ATTACHMENTINCLUSION_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "AttachmentInclusion":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        not_included: typing.Callable[[], T_Result],
        included_on_next_submission: typing.Callable[[], T_Result],
        included_on_all_submissions: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is AttachmentInclusion.NOT_INCLUDED:
            return not_included()
        if self is AttachmentInclusion.INCLUDED_ON_NEXT_SUBMISSION:
            return included_on_next_submission()
        if self is AttachmentInclusion.INCLUDED_ON_ALL_SUBMISSIONS:
            return included_on_all_submissions()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import typing

from ......core.api_error import ApiError
from ..types.payer_plan_group_payer_does_not_match_insurance_card_error import (
    PayerPlanGroupPayerDoesNotMatchInsuranceCardError,
)


class PayerPlanGroupPayerDoesNotMatchInsuranceCardHttpError(ApiError):
    def __init__(
        self,
        body: PayerPlanGroupPayerDoesNotMatchInsuranceCardError,
        headers: typing.Optional[typing.Dict[str, str]] = None,
    ):
        super().__init__(status_code=422, headers=headers, body=body)
